<?php
/**
 * The main template for implementing Theme/Customzer Options
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Implements Rock Star theme options into Theme Customizer.
 *
 * @param $wp_customize Theme Customizer object
 * @return void
 *
 * @since Rock Star 1.0
 */
function rock_star_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport			= 'postMessage';

	/**
	  * Set priority of blogname (Site Title) to 1.
	  *  Strangly, if more than two options is added, Site title is moved below Tagline. This rectifies this issue.
	  */
	$wp_customize->get_control( 'blogname' )->priority			= 1;

	$wp_customize->get_setting( 'blogdescription' )->transport	= 'postMessage';

	$options  = rock_star_get_theme_options();
	$defaults = rock_star_get_default_theme_options();

	//Custom Controls
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/custom-controls.php';

	// Move title_tagline (added to Site Title and Tagline section in Theme Customizer)
	$wp_customize->add_setting( 'rock_star_theme_options[move_title_tagline]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['move_title_tagline'],
		'sanitize_callback' => 'rock_star_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'rock_star_theme_options[move_title_tagline]', array(
		'label'    => esc_html__( 'Check to move Site Title and Tagline before logo', 'rock-star-pro' ),
		'priority' => 103,
		'section'  => 'title_tagline',
		'settings' => 'rock_star_theme_options[move_title_tagline]',
		'type'     => 'checkbox',
	) );

	// Header Options (added to Header section in Theme Customizer)
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/header-options.php';


   	//Additional Menu Options
	$wp_customize->add_section( 'rock_star_menu_options', array(
		'description'	=> esc_html__( 'Extra Menu Options specific to this theme', 'rock-star-pro' ),
		'priority' 		=> 105,
		'title'    		=> esc_html__( 'Menu Options', 'rock-star-pro' ),
	) );

	$wp_customize->add_setting( 'rock_star_theme_options[primary_menu_disable]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['primary_menu_disable'],
		'sanitize_callback' => 'rock_star_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'rock_star_theme_options[primary_menu_disable]', array(
		'label'    => esc_html__( 'Check to disable Primary Menu', 'rock-star-pro' ),
		'section'  => 'rock_star_menu_options',
		'settings' => 'rock_star_theme_options[primary_menu_disable]',
		'type'     => 'checkbox',
	) );

	//Theme Options
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/theme-options.php';

	// Color Options
	// Moved from Default Color Control to Catbase Color Options
	$wp_customize->get_control( 'background_color' )->section = 'background_image';
	$wp_customize->get_control( 'header_textcolor' )->section = 'rock_star_header_color_options';

   	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/color-options.php';

	//Featured Slider
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/featured-slider.php';

	//Featured Content Setting
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/featured-content.php';

	//News Ticker
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/news-ticker.php';

	//Social Links
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/social-icons.php';

	// Reset all settings to default
	$wp_customize->add_section( 'rock_star_reset_all_settings', array(
		'description'	=> esc_html__( 'Caution: Reset all settings to default', 'rock-star-pro' ),
		'priority' 		=> 700,
		'title'    		=> esc_html__( 'Reset all settings', 'rock-star-pro' ),
	) );

	$wp_customize->add_setting( 'rock_star_theme_options[reset_all_settings]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['reset_all_settings'],
		'sanitize_callback' => 'rock_star_sanitize_checkbox',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'rock_star_theme_options[reset_all_settings]', array(
		'label'    => esc_html__( 'Check to reset all settings to default', 'rock-star-pro' ),
		'section'  => 'rock_star_reset_all_settings',
		'settings' => 'rock_star_theme_options[reset_all_settings]',
		'type'     => 'checkbox',
	) );
	// Reset all settings to default end


	//Important Links
	$wp_customize->add_section( 'important_links', array(
		'priority' => 999,
		'title'    => esc_html__( 'Important Links', 'rock-star-pro' ),
	) );

	$wp_customize->add_setting( 'important_links', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new rock_star_important_links( $wp_customize, 'important_links', array(
		'label'    => esc_html__( 'Important Links', 'rock-star-pro' ),
		'section'  => 'important_links',
		'settings' => 'important_links',
		'type'     => 'important_links',
    ) ) );
    //Important Links End
}
add_action( 'customize_register', 'rock_star_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously for Rock Star.
 * And flushes out all transient data on preview
 *
 * @since Rock Star 1.0
 */
function rock_star_customize_preview() {
	wp_enqueue_script( 'rock_star_customizer', get_template_directory_uri() . '/js/customizer.min.js', array( 'customize-preview' ), '20120827', true );

	//Flush transients
	rock_star_flush_transients();
}
add_action( 'customize_preview_init', 'rock_star_customize_preview' );


/**
 * Custom scripts and styles on customize.php for rock-star.
 *
 * @since Rock Star Pro 1.0
 */
function rock_star_customize_scripts() {
	wp_enqueue_script( 'rock_star_customizer_custom', get_template_directory_uri() . '/js/customizer-custom-scripts.min.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '20150630', true );

	$rock_star_data = array(
		'rock_star_color_list' => rock_star_color_list(),
		'reset_message'        => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'rock-star-pro' )
	);

	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'rock_star_customizer_custom', 'rock_star_data', $rock_star_data );
}
add_action( 'customize_controls_enqueue_scripts', 'rock_star_customize_scripts');


/**
 * Returns list of color keys of array with default values for each color scheme as index
 *
 * @since Rock Star Pro 3.0.2
 */
function rock_star_color_list() {
	// Get default color scheme values
	$default      = rock_star_default_light_color_options();

	// Get default dark color scheme values
	$default_dark = rock_star_get_default_theme_options();

	$rock_star_color_list['background_color']['light']	= $default['background_color'];
	$rock_star_color_list['background_color']['dark']	= $default_dark['background_color'];

	$rock_star_color_list['header_textcolor']['light']	= $default['header_textcolor'];
	$rock_star_color_list['header_textcolor']['dark']	= $default_dark['header_textcolor'];


	// Get coloy keys for all other options except menu
	$rock_star_get_color_list = array_merge(
		rock_star_get_basic_color_options(),
		rock_star_get_header_color_options(),
		rock_star_get_content_color_options(),
		rock_star_get_sidebar_color_options(),
		rock_star_get_pagination_color_options(),
		rock_star_get_footer_color_options(),
		rock_star_get_scrollup_color_options(),
		rock_star_get_slider_color_options(),
		rock_star_get_featured_content_color_options(),
		rock_star_get_menu_color_options()
	);

	// Set light and dark color keys with default values for each color scheme as index
	foreach( $rock_star_get_color_list as $key => $color_option ) {
		$lower_color_option	=	$key;

		$rock_star_color_list[ 'rock_star_theme_options[' . $lower_color_option . ']' ]['light'] 	= $default[ $lower_color_option ];
		$rock_star_color_list[ 'rock_star_theme_options[' . $lower_color_option . ']' ]['dark'] 	= $default_dark[ $lower_color_option ];
	}

	return $rock_star_color_list;
}


/**
 * Function to reset date with respect to condition
 */
function rock_star_reset_data() {
	$options  = rock_star_get_theme_options();
    if ( $options['reset_all_settings'] ) {
    	remove_theme_mods();

        // Flush out all transients	on reset
        rock_star_flush_transients();

        return;
    }

	$defaults = rock_star_get_default_theme_options();
    if ( $options['reset_footer_content'] ) {
    	//Reset Footer Editor Options
		$options['footer_content']       = $defaults['footer_content'];
		$options['reset_footer_content'] = 0;

		set_theme_mod( 'rock_star_theme_options', $options );
		delete_transient( 'rock_star_footer_content' );
    }

    if ( $options['reset_typography'] ) {
    	//Reset Font Family Options
        $font_family_options	=	array(
			'title_font',
			'body_font',
			'tagline_font',
			'menu_font',
			'content_title_font',
			'content_font',
			'headings_font'
		);
        $options['reset_typography'] = 0;

		foreach ( $font_family_options as $font_family_option ) {
			$options[ $font_family_option ] = $defaults[ $font_family_option ];
		}

        set_theme_mod( 'rock_star_theme_options', $options );
    }
}
add_action( 'customize_save_after', 'rock_star_reset_data' );


//Active callbacks for customizer
require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/active-callbacks.php';

//Sanitize functions for customizer
require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/sanitize-functions.php';