<?php
/**
* The template for adding Featured Slider Options in Customizer
*
* @package Catch Themes
* @subpackage Rock Star Pro
* @since Rock Star 1.0
*/

$wp_customize->add_section( 'rock_star_featured_slider', array(
	'priority'      => 400,
	'title'			=> esc_html__( 'Featured Slider', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[featured_slider_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_option'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$featured_slider_content_options = rock_star_featured_slider_content_options();
$choices = array();
foreach ( $featured_slider_content_options as $featured_slider_content_option ) {
	$choices[$featured_slider_content_option['value']] = $featured_slider_content_option['label'];
}

$wp_customize->add_control( 'rock_star_theme_options[featured_slider_option]', array(
	'choices'   => $choices,
	'label'    	=> esc_html__( 'Enable Slider on', 'rock-star-pro' ),
	'priority'	=> '2',
	'section'  	=> 'rock_star_featured_slider',
	'settings' 	=> 'rock_star_theme_options[featured_slider_option]',
	'type'    	=> 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[featured_slide_transition_effect]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slide_transition_effect'],
	'sanitize_callback'	=> 'rock_star_sanitize_select',
) );

$featured_slide_transition_effects = rock_star_featured_slide_transition_effects();
$choices = array();
foreach ( $featured_slide_transition_effects as $featured_slide_transition_effect ) {
	$choices[$featured_slide_transition_effect['value']] = $featured_slide_transition_effect['label'];
}

$wp_customize->add_control( 'rock_star_theme_options[featured_slide_transition_effect]' , array(
	'active_callback'	=> 'rock_star_is_slider_active',
	'choices'  	=> $choices,
	'label'		=> esc_html__( 'Transition Effect', 'rock-star-pro' ),
	'priority'	=> '3',
	'section'  	=> 'rock_star_featured_slider',
	'settings' 	=> 'rock_star_theme_options[featured_slide_transition_effect]',
	'type'	  	=> 'select',
	)
);

$wp_customize->add_setting( 'rock_star_theme_options[featured_slide_transition_delay]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slide_transition_delay'],
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( 'rock_star_theme_options[featured_slide_transition_delay]' , array(
	'active_callback'	=> 'rock_star_is_slider_active',
	'description'	=> esc_html__( 'seconds(s)', 'rock-star-pro' ),
	'input_attrs' => array(
    	'style' => 'width: 40px;'
	),
	'label'    		=> esc_html__( 'Transition Delay', 'rock-star-pro' ),
	'priority'		=> '4',
	'section'  		=> 'rock_star_featured_slider',
	'settings' 		=> 'rock_star_theme_options[featured_slide_transition_delay]',
	)
);

$wp_customize->add_setting( 'rock_star_theme_options[featured_slide_transition_length]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slide_transition_length'],
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( 'rock_star_theme_options[featured_slide_transition_length]' , array(
	'active_callback'	=> 'rock_star_is_slider_active',
	'description'	=> esc_html__( 'seconds(s)', 'rock-star-pro' ),
	'input_attrs' => array(
    	'style' => 'width: 40px;'
	),
	'label'    		=> esc_html__( 'Transition Length', 'rock-star-pro' ),
	'priority'		=> '5',
	'section'  		=> 'rock_star_featured_slider',
	'settings' 		=> 'rock_star_theme_options[featured_slide_transition_length]',
	)
);

$wp_customize->add_setting( 'rock_star_theme_options[featured_slider_image_loader]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_image_loader'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$featured_slider_image_loader_options = rock_star_featured_slider_image_loader();
$choices = array();
foreach ( $featured_slider_image_loader_options as $featured_slider_image_loader_option ) {
	$choices[$featured_slider_image_loader_option['value']] = $featured_slider_image_loader_option['label'];
}

$wp_customize->add_control( 'rock_star_theme_options[featured_slider_image_loader]', array(
	'active_callback'	=> 'rock_star_is_slider_active',
	'choices'   => $choices,
	'label'    	=> esc_html__( 'Image Loader', 'rock-star-pro' ),
	'priority'	=> '6',
	'section'  	=> 'rock_star_featured_slider',
	'settings' 	=> 'rock_star_theme_options[featured_slider_image_loader]',
	'type'    	=> 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[featured_slider_enable_social_icons]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_enable_social_icons'],
	'sanitize_callback'	=> 'rock_star_sanitize_checkbox',
) );


$wp_customize->add_control(  'rock_star_theme_options[featured_slider_enable_social_icons]', array(
	'active_callback'	=> 'rock_star_is_slider_active',
	'label'		=> esc_html__( 'Enable Social Icons in Featured Slider', 'rock-star-pro' ),
	'priority'	=> '7',
	'section'   => 'rock_star_featured_slider',
	'settings'  => 'rock_star_theme_options[featured_slider_enable_social_icons]',
	'type'		=> 'checkbox',
) );

$wp_customize->add_setting( 'rock_star_theme_options[featured_slider_type]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_type'],
	'sanitize_callback'	=> 'rock_star_sanitize_select',
) );


$featured_slider_types = rock_star_featured_slider_types();
$choices = array();
foreach ( $featured_slider_types as $featured_slider_type ) {
	$choices[$featured_slider_type['value']] = $featured_slider_type['label'];
}

$wp_customize->add_control( 'rock_star_theme_options[featured_slider_type]', array(
	'active_callback'	=> 'rock_star_is_slider_active',
	'choices'  	=> $choices,
	'label'    	=> esc_html__( 'Select Slider Type', 'rock-star-pro' ),
	'priority'	=> '7',
	'section'  	=> 'rock_star_featured_slider',
	'settings' 	=> 'rock_star_theme_options[featured_slider_type]',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[featured_slide_number]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slide_number'],
	'sanitize_callback'	=> 'rock_star_sanitize_number_range',
) );

$wp_customize->add_control( 'rock_star_theme_options[featured_slide_number]' , array(
	'active_callback'	=> 'rock_star_is_demo_slider_inactive',
	'description'	=> esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'rock-star-pro' ),
	'input_attrs' 	=> array(
        'style' => 'width: 45px;',
        'min'   => 0,
        'max'   => 20,
        'step'  => 1,
    	),
	'label'    		=> esc_html__( 'No of Slides', 'rock-star-pro' ),
	'priority'		=> '8',
	'section'  		=> 'rock_star_featured_slider',
	'settings' 		=> 'rock_star_theme_options[featured_slide_number]',
	'type'	   		=> 'number',
	'transport'		=> 'postMessage'
	)
);

$wp_customize->add_setting( 'rock_star_theme_options[exclude_slider_post]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['exclude_slider_post'],
	'sanitize_callback'	=> 'rock_star_sanitize_checkbox',
) );

$wp_customize->add_control(  'rock_star_theme_options[exclude_slider_post]', array(
	'active_callback'	=> 'rock_star_is_post_slider_active',
	'label'		=> esc_html__( 'Check to exclude Slider post from Homepage posts', 'rock-star-pro' ),
	'priority'	=> '9',
	'section'   => 'rock_star_featured_slider',
	'settings'  => 'rock_star_theme_options[exclude_slider_post]',
	'type'		=> 'checkbox',
) );

//loop for featured post sliders
for ( $i=1; $i <=  $options['featured_slide_number'] ; $i++ ) {
	$wp_customize->add_setting( 'rock_star_theme_options[featured_slider_post_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'rock_star_sanitize_page',
	) );

	$wp_customize->add_control( 'rock_star_theme_options[featured_slider_post_'. $i .']', array(
		'active_callback'	=> 'rock_star_is_post_slider_active',
		'input_attrs' => array(
    		'style' => 'width: 80px;'
		),
		'label'    	=> esc_html__( 'Featured Post', 'rock-star-pro' ) . ' # ' . $i ,
		'priority'	=>  '10' . $i,
		'section'  	=> 'rock_star_featured_slider',
		'settings' 	=> 'rock_star_theme_options[featured_slider_post_'. $i .']',
		'type'	   	=> 'text',
		)
	);
}

//loop for featured page sliders
for ( $i=1; $i <= $options['featured_slide_number'] ; $i++ ) {
	$wp_customize->add_setting( 'rock_star_theme_options[featured_slider_page_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'rock_star_sanitize_page',
	) );

	$wp_customize->add_control( 'rock_star_theme_options[featured_slider_page_'. $i .']', array(
		'active_callback'	=> 'rock_star_is_page_slider_active',
		'label'    	=> esc_html__( 'Featured Page', 'rock-star-pro' ) . ' # ' . $i ,
		'priority'	=> '11' . $i,
		'section'  	=> 'rock_star_featured_slider',
		'settings' 	=> 'rock_star_theme_options[featured_slider_page_'. $i .']',
		'type'	   	=> 'dropdown-pages',
	) );
}

$wp_customize->add_setting( 'rock_star_theme_options[featured_slider_select_category]', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'rock_star_sanitize_category_list',
) );

$wp_customize->add_control( new rock_star_customize_dropdown_categories_control( $wp_customize, 'rock_star_theme_options[featured_slider_select_category]', array(
	'active_callback'	=> 'rock_star_is_category_slider_active',
    'label'   	=> __('Select Categories', 'rock-star-pro' ),
    'name' 		=> 'rock_star_theme_options[featured_slider_select_category]',
	'priority'	=> '10',
    'section'  	=> 'rock_star_featured_slider',
    'settings' 	=> 'rock_star_theme_options[featured_slider_select_category]',
    'type'     	=> 'dropdown-categories',
) ) );

$priority	=	'13';
//loop for featured image slider
for( $i = 1; $i <= $options['featured_slide_number'] ; $i++ ){
	if ( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
		$priority++;

	$wp_customize->add_setting( 'rock_star_theme_options[featured_slider_note_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new rock_star_note_control( $wp_customize, 'featured_slider_note_'. $i, array(
		'active_callback'	=> 'rock_star_is_image_slider_active',
        'label'		=> esc_html__( 'Featured Slide #', 'rock-star-pro' ) . $i,
		'priority'	=> $priority . '.' . $i,
        'section'  	=> 'rock_star_featured_slider',
        'settings'	=> 'rock_star_theme_options[featured_slider_note_'. $i .']',
        'type'     	=> 'description',
		) ) );

	$wp_customize->add_setting( 'rock_star_theme_options[featured_slider_image_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'rock_star_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'rock_star_theme_options[featured_slider_image_'. $i .']', array(
		'active_callback'	=> 'rock_star_is_image_slider_active',
		'label'		=> esc_html__( 'Image', 'rock-star-pro' ),
		'priority'	=> $priority . '.' . $i .$i,
		'section'   => 'rock_star_featured_slider',
        'settings'  => 'rock_star_theme_options[featured_slider_image_'. $i .']',
	) ) );

	$wp_customize->add_setting( 'rock_star_theme_options[featured_link_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'rock_star_theme_options[featured_link_'. $i .']', array(
		'active_callback'	=> 'rock_star_is_image_slider_active',
		'label'		=> esc_html__( 'Link', 'rock-star-pro' ),
        'priority'	=> $priority . '.' .$i . $i  . $i,
		'section'   => 'rock_star_featured_slider',
        'settings'  => 'rock_star_theme_options[featured_link_'. $i .']',
	) );

	$wp_customize->add_setting( 'rock_star_theme_options[featured_target_'. $i .']', array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'rock_star_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'rock_star_theme_options[featured_target_'. $i .']', array(
		'active_callback'	=> 'rock_star_is_image_slider_active',
		'label'		=> esc_html__( 'Check to Open Link in New Window/Tab', 'rock-star-pro' ),
        'priority'	=> $priority . '.' .$i  .$i  . $i . $i,
		'section'   => 'rock_star_featured_slider',
        'settings'  => 'rock_star_theme_options[featured_target_'. $i .']',
		'type'		=> 'checkbox',
    ) );

    $wp_customize->add_setting( 'rock_star_theme_options[featured_title_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'rock_star_theme_options[featured_title_'. $i .']', array(
		'active_callback'	=> 'rock_star_is_image_slider_active',
		'label'		=> esc_html__( 'Title', 'rock-star-pro' ),
        'priority'	=> $priority . '.' .$i .  $i.  $i .$i . $i,
		'section'   => 'rock_star_featured_slider',
        'settings'  => 'rock_star_theme_options[featured_title_'. $i .']',
		'type'		=> 'text',
    ) );

    $wp_customize->add_setting( 'rock_star_theme_options[featured_content_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'rock_star_theme_options[featured_content_'. $i .']', array(
		'active_callback'	=> 'rock_star_is_image_slider_active',
		'label'		=> esc_html__( 'Content', 'rock-star-pro' ),
        'priority'	=> $priority . '.' . $i . $i .  $i . $i . $i . $i,
		'section'   => 'rock_star_featured_slider',
        'settings'  => 'rock_star_theme_options[featured_content_'. $i .']',
		'type'		=> 'textarea',
    ) );
}