<?php
/**
* The template for adding News Ticker Settings in Customizer
*
* @package Catch Themes
* @subpackage Rock Star Pro
* @since Rock Star 1.0
*/

$wp_customize->add_section( 'rock_star_news_ticker_settings', array(
	'priority'      => 500,
	'title'			=> esc_html__( 'News Ticker', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['news_ticker_option'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$featured_slider_content_options = rock_star_featured_slider_content_options();
$choices = array();
foreach ( $featured_slider_content_options as $featured_slider_content_option ) {
	$choices[$featured_slider_content_option['value']] = $featured_slider_content_option['label'];
}

$wp_customize->add_control( 'rock_star_theme_options[news_ticker_option]', array(
	'choices'  	=> $choices,
	'label'    	=> esc_html__( 'Enable News Ticker on', 'rock-star-pro' ),
	'priority'	=> '1',
	'section'  	=> 'rock_star_news_ticker_settings',
	'settings' 	=> 'rock_star_theme_options[news_ticker_option]',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_position]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['news_ticker_position'],
	'sanitize_callback'	=> 'rock_star_sanitize_select',
) );

$news_ticker_positions = rock_star_news_ticker_positions();
$choices = array();
foreach ( $news_ticker_positions as $news_ticker_position ) {
	$choices[$news_ticker_position['value']] = $news_ticker_position['label'];
}

$wp_customize->add_control( 'rock_star_theme_options[news_ticker_position]', array(
	'active_callback'	=> 'rock_star_is_news_ticker_active',
	'choices'  	=> $choices,
	'label'    	=> esc_html__( 'News Ticker Position', 'rock-star-pro' ),
	'priority'	=> '3',
	'section'  	=> 'rock_star_news_ticker_settings',
	'settings' 	=> 'rock_star_theme_options[news_ticker_position]',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_transition_effect]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['news_ticker_transition_effect'],
	'sanitize_callback'	=> 'rock_star_sanitize_select',
) );

$news_ticker_transition_effects = rock_star_featured_slide_transition_effects();
$choices = array();
foreach ( $news_ticker_transition_effects as $news_ticker_transition_effect ) {
	$choices[$news_ticker_transition_effect['value']] = $news_ticker_transition_effect['label'];
}

$wp_customize->add_control( 'rock_star_theme_options[news_ticker_transition_effect]' , array(
	'active_callback' => 'rock_star_is_news_ticker_active',
	'choices'         => $choices,
	'label'           => esc_html__( 'Transition Effect', 'rock-star-pro' ),
	'priority'        => '4',
	'section'         => 'rock_star_news_ticker_settings',
	'settings'        => 'rock_star_theme_options[news_ticker_transition_effect]',
	'type'            => 'select',
	)
);

$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_type]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['news_ticker_type'],
	'sanitize_callback'	=> 'rock_star_sanitize_select',
) );

$news_ticker_types = rock_star_news_ticker_types();
$choices = array();
foreach ( $news_ticker_types as $news_ticker_type ) {
	$choices[$news_ticker_type['value']] = $news_ticker_type['label'];
}

$wp_customize->add_control( 'rock_star_theme_options[news_ticker_type]', array(
	'active_callback'	=> 'rock_star_is_news_ticker_active',
	'choices'  	=> $choices,
	'label'    	=> esc_html__( 'Select Ticker Type', 'rock-star-pro' ),
	'priority'	=> '3',
	'section'  	=> 'rock_star_news_ticker_settings',
	'settings' 	=> 'rock_star_theme_options[news_ticker_type]',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_label]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['news_ticker_label'],
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'rock_star_theme_options[news_ticker_label]' , array(
	'active_callback'	=> 'rock_star_is_demo_news_ticker_inactive',
	'description'	=> esc_html__( 'Leave field empty if you want to remove Headline', 'rock-star-pro' ),
	'label'    		=> esc_html__( 'News Ticker Label', 'rock-star-pro' ),
	'priority'		=> '4',
	'section'  		=> 'rock_star_news_ticker_settings',
	'settings' 		=> 'rock_star_theme_options[news_ticker_label]',
	'type'	   		=> 'text',
	)
);

$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_number]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['news_ticker_number'],
	'sanitize_callback'	=> 'rock_star_sanitize_number_range',
) );

$wp_customize->add_control( 'rock_star_theme_options[news_ticker_number]' , array(
	'active_callback'	=> 'rock_star_is_demo_news_ticker_inactive',
	'description'	=> esc_html__( 'Save and refresh the page if No. of News Ticker is changed (Max no of News Ticker is 20)', 'rock-star-pro' ),
	'input_attrs' 	=> array(
        'style' => 'width: 45px;',
        'min'   => 0,
        'max'   => 20,
        'step'  => 1,
    	),
	'label'    		=> esc_html__( 'No of News Ticker', 'rock-star-pro' ),
	'priority'		=> '6',
	'section'  		=> 'rock_star_news_ticker_settings',
	'settings' 		=> 'rock_star_theme_options[news_ticker_number]',
	'type'	   		=> 'number',
	'transport'		=> 'postMessage'
	)
);

$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_select_category]', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'rock_star_sanitize_category_list',
) );

$wp_customize->add_control( new rock_star_customize_dropdown_categories_control( $wp_customize, 'rock_star_news_ticker_select_category', array(
    'active_callback'	=> 'rock_star_is_cagetory_news_ticker_active',
    'label'   	=> esc_html__( 'Select Categories', 'rock-star-pro' ),
    'name' 		=> 'rock_star_theme_options[news_ticker_select_category]',
    'section'  	=> 'rock_star_news_ticker_settings',
    'settings' 	=> 'rock_star_theme_options[news_ticker_select_category]',
    'type'     	=> 'dropdown-categories',
) ) );

for ( $i=1; $i <=  $options['news_ticker_number'] ; $i++ ) {
	//Post News Ticker
	$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_post_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'rock_star_sanitize_page',
		)
	);

	$wp_customize->add_control( 'rock_star_news_ticker_post_'. $i, array(
		'active_callback'	=> 'rock_star_is_post_news_ticker_active',
		'input_attrs' => array(
        	'style' => 'width: 200px;'
    	),
		'label'    	=> esc_html__( 'Post', 'rock-star-pro' ) . ' ' . $i ,
		'section'  	=> 'rock_star_news_ticker_settings',
		'settings' 	=> 'rock_star_theme_options[news_ticker_post_'. $i .']',
		'type'	   	=> 'text',
		)
	);

	//Page News Ticker
	$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_page_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'rock_star_sanitize_page',
	) );

	$wp_customize->add_control( 'rock_star_news_ticker_page_'. $i .'', array(
		'active_callback' => 'rock_star_is_page_news_ticker_active',
		'label'           => esc_html__( 'Page', 'rock-star-pro' ) . ' ' . $i ,
		'section'         => 'rock_star_news_ticker_settings',
		'settings'        => 'rock_star_theme_options[news_ticker_page_'. $i .']',
		'type'            => 'dropdown-pages',
	) );

	//Text News Ticker
	$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_note_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new rock_star_note_control( $wp_customize, 'news_ticker_note_'. $i, array(
		'active_callback' => 'rock_star_is_text_news_ticker_active',
		'label'           => esc_html__( 'News Ticker #', 'rock-star-pro' ) .  $i,
		'section'         => 'rock_star_news_ticker_settings',
		'settings'        => 'rock_star_theme_options[news_ticker_note_'. $i .']',
		'type'            => 'description',
		) ) );

	$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_link_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'rock_star_theme_options[news_ticker_link_'. $i .']', array(
		'active_callback' => 'rock_star_is_text_news_ticker_active',
		'label'           => esc_html__( 'Link', 'rock-star-pro' ),
		'section'         => 'rock_star_news_ticker_settings',
		'settings'        => 'rock_star_theme_options[news_ticker_link_'. $i .']',
	) );

	$wp_customize->add_setting( 'rock_star_theme_options[news_ticker_target_'. $i .']', array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'rock_star_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'rock_star_theme_options[news_ticker_target_'. $i .']', array(
		'active_callback' => 'rock_star_is_text_news_ticker_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'rock-star-pro' ),
		'section'         => 'rock_star_news_ticker_settings',
		'settings'        => 'rock_star_theme_options[news_ticker_target_'. $i .']',
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'rock_star_theme_options[news_ticker_title_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'rock_star_theme_options[news_ticker_title_'. $i .']', array(
		'active_callback' => 'rock_star_is_text_news_ticker_active',
		'label'           => esc_html__( 'Title', 'rock-star-pro' ),
		'section'         => 'rock_star_news_ticker_settings',
		'settings'        => 'rock_star_theme_options[news_ticker_title_'. $i .']',
		'type'            => 'textarea',
    ) );
}