<?php
/**
 * Implement Default Theme/Customizer Options
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */


/**
 * Returns the default options for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_get_default_theme_options() {

	$theme_data = wp_get_theme();

	$default_theme_options = array(
		//Site Title an Tagline
		'move_title_tagline'                              => 0,

		//Preloader Image
		'enable_preloader'                                => 0,
		'preloader_image'                                 => get_template_directory_uri() . '/images/gallery/loader-icon-300x150.png',

		//Layout
		'theme_layout'                                    => 'no-sidebar-full-width',
		'woocommerce_layout'                              => 'no-sidebar-full-width',
		'single_page_post_layout'                         => 'right-sidebar',
		'content_layout'                                  => 'excerpt-image-top',
		'archive_top_layout'                              => 'three-columns',
		'single_post_image_size'                          => 'disabled',

		//Header Image
		'enable_featured_header_image'                    => 'exclude-home',
		'featured_header_image_position'                  => 'after-slider',
		'featured_image_size'                             => 'full',
		'featured_header_image_url'                       => '',
		'featured_header_image_alt'                       => '',
		'featured_header_image_base'                      => 0,

		//Navigation
		'primary_menu_disable'                            => 0,

		//Breadcrumb Options
		'breadcrumb_option'                               => 0,
		'$breadcrumb_on_homepage'                         => 0,
		'breadcrumb_seperator'                            => '&raquo;',

		//Comment Options
		'comment_option'                                  => 'use-wordpress-setting',
		'disable_notes'                                   => 0,
		'disable_website_field'                           => 0,

		//Custom CSS
		'custom_css'                                      => '',

		//Scrollup Options
		'disable_scrollup'                                => 0,

		//Header Right Sidebar Options
		'disable_header_right_sidebar'                    => 0,

		//Excerpt Options
		'excerpt_length'                                  => '45',
		'excerpt_more_text'                               => esc_html__( 'Read More ...', 'rock-star-pro' ),

		//Homepage / Frontpage Settings
		'front_page_category'                             => '0',
		'latest_posts_title'                              => '',

		//Pagination Options
		'pagination_type'                                 => 'default',

		//Search Options
		'search_text'                                     => esc_html__( 'Search...', 'rock-star-pro' ),

		//Feed Redirect
		'feed_redirect'                                   => '',

		//Single Post Navigation
		'disable_single_post_navigation'                  => 0,

		//Font Family Options
		'body_font'                                       => 'sans-serif',
		'title_font'                                      => 'courgette',
		'tagline_font'                                    => 'sans-serif',
		'menu_font'                                       => 'sans-serif',
		'content_title_font'                              => 'sans-serif',
		'content_font'                                    => 'courgette',
		'headings_font'                                   => 'sans-serif',
		'reset_typography'                                => 0,

		//Footer Editor Options
		'footer_content'                                  => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'rock-star-pro' ), '[the-year]', '[site-link]' ) . ' &#124; ' . $theme_data->get( 'Name') . '&nbsp;' . esc_html__( 'by', 'rock-star-pro' ). '&nbsp;<a target="_blank" href="'. $theme_data->get( 'AuthorURI' ) .'">'. $theme_data->get( 'Author' ) .'</a>',
		'reset_footer_content'                            => 0,

		//Update Notifier
		'update_notifier'                                 => 0,

		//Basic Color Options
		'color_scheme'                                    => 'dark',
		'background_color'                                => '#000000',
		'text_color'                                      => '#cccccc',
		'link_color'                                      => '#dddddd',
		'link_hover_color'                                => '#404040',

		//Header Color Options
		'header_textcolor'                                => '#ffffff',
		'header_background_color'                         => '#000000',
		'site_title_hover_color'                          => '#e8554e',
		'tagline_color'                                   => '#ffffff',

		//Content Color Options
		'content_wrapper_background_color'                => '',
		'content_background_color'                        => '',
		'content_title_color'                             => '#dddddd',
		'content_title_hover_color'                       => '#ffffff',
		'content_meta_color'                              => '#dddddd',
		'content_meta_hover_color'                        => '#ffffff',
		'sticky_post_label_background_color'              => '#000000',
		'sticky_post_label_text_color'                    => '#ffffff',

		//Sidebar Color Options
		'sidebar_background_color'                        => '',
		'sidebar_widget_title_color'                      => '#dddddd',
		'sidebar_widget_text_color'                       => '#cccccc',
		'sidebar_widget_link_color'                       => '#dddddd',

		//Pagination Color Options
		'pagination_background_color'                     => '',
		'pagination_hover_background_color'               => '#e8554e',
		'pagination_text_color'                           => '#cccccc',
		'pagination_link_color'                           => '#ffffff',
		'pagination_border_color'                         => '#dddddd',
		'pagination_hover_active_color'                   => '#ffffff',
		'pagination_hover_active_border_color'            => '#e8554e',

		//Footer Color Options
		'footer_background_color'                         => '#111111',
		'footer_text_color'                               => '#cccccc',
		'footer_link_color'                               => '#b7b7b7',
		'footer_link_hover_color'                         => '#ffffff',
		'footer_sidebar_area_background_color'            => '',
		'footer_widget_background_color'                  => '',
		'footer_widget_title_color'                       => '#dddddd',
		'footer_widget_text_color'                        => '#cccccc',
		'footer_widget_link_color'                        => '#dddddd',
		'footer_widget_link_hover_color'                  => '#ffffff',

		//Scrollup Color Options
		'scrollup_background_color'                       => '#333333',
		'scrollup_hover_background_color'                 => '#000000',
		'scrollup_text_color'                             => '#ffffff',
		'scrollup_hover_text_color'                       => '#ffffff',

		//Featured Content Color Options
		'featured_content_background_color'               => '',
		'featured_content_title_color'                    => '#dddddd',
		'featured_content_title_hover_color'              => '#ffffff',
		'featured_content_text_color'                     => '#cccccc',
		'featured_content_link_color'                     => '#dddddd',
		'featured_content_link_hover_color'               => '#ffffff',

		//Featured Content Color Options
		'news_ticker_background_color'                    => '#222222',
		'news_ticker_label_color'                         => '#e8554e',
		'news_ticker_label_border_color'                  => '#ffffff',
		'news_ticker_title_color'                         => '#ffffff',
		'news_ticker_title_hover_color'                   => '#dddddd',

		//Slider Color Options
		'slider_content_background_color'                 => '',
		'slider_text_color'                               => '#ffffff',
		'slider_link_color'                               => '#e8554e',
		'slider_link_hover_color'                         => '#ffffff',
		'slider_title_color'                              => '#ffffff',
		'slider_title_hover_color'                        => '#dddddd',
		'slider_button_background_color'                  => '',
		'slider_button_border_color'                      => '#ffffff',
		'slider_button_text_color'                        => '#ffffff',
		'slider_button_hover_background_color'            => '#e8554e',
		'slider_button_hover_border_color'                => '#e8554e',
		'slider_button_hover_text_color'                  => '#ffffff',
		'slider_control_background_color'                 => '#000000',
		'slider_control_text_color'                       => '#ffffff',
		'slider_control_hover_background_color'           => '#e8554e',
		'slider_control_hover_text_color'                 => '#ffffff',
		'slider_pager_color'                              => '#ffffff',
		'slider_pager_hover_color'                        => '#e8554e',

		//Primary Menu Color Options
		'menu_background_color'                           => '',
		'menu_color'                                      => '#ffffff',
		'hover_active_background_color'                   => '',
		'hover_active_text_color'                         => '#e8554e',
		'sub_menu_background_color'                       => '#000000',
		'sub_menu_text_color'                             => '#ffffff',
		'sub_menu_hover_background_color'                 => '#000000',
		'sub_menu_hover_text_color'                       => '#e8554e',

		//Featured Content Options
		'featured_content_option'                         => 'disabled',
		'featured_content_layout'                         => 'three-columns',
		'featured_content_position'                       => 1,
		'featured_content_headline'                       => '',
		'featured_content_subheadline'                    => '',
		'featured_content_type'                           => 'demo-featured-content',
		'featured_content_number'                         => '3',
		'featured_content_select_category'                => '0',
		'featured_content_show'                           => 'excerpt',

		'featured_content_background_image'               => get_template_directory_uri() . '/images/gallery/background-dark-1920x1080.jpg',
		'featured_content_background_display_position'    => 'bottom',
		'featured_content_background_repeat'              => 'repeat',
		'featured_content_background_attachment'          => 'fixed',

		//News Ticker Options
		'news_ticker_option'                              => 'homepage',
		'news_ticker_position'                            => 'below-slider-header-image',
		'news_ticker_type'                                => 'demo-news-ticker',
		'news_ticker_label'                               => '',
		'news_ticker_transition_effect'                   => 'flipVert',
		'news_ticker_number'                              => '4',
		'news_ticker_select_category'                     => '0',
		'news_ticker_show'                                => 0,

		//Featured Slider Options
		'featured_slider_option'                          => 'homepage',
		'featured_slider_image_loader'                    => 'true',
		'featured_slider_enable_social_icons'             => 0,
		'featured_slide_transition_effect'                => 'fadeout',
		'featured_slide_transition_delay'                 => '4',
		'featured_slide_transition_length'                => '1',
		'featured_slider_type'                            => 'demo-featured-slider',
		'featured_slide_number'                           => '4',
		'featured_slider_select_category'                 => '0',
		'exclude_slider_post'                             => 0,

		//Social Links
		'social_icon_size'                                => '20',
		'custom_social_icons'                             => '1',

		//Reset all settings
		'reset_all_settings'                              => 0,
	);

	return apply_filters( 'rock_star_default_theme_options', $default_theme_options );
}

/**
 * Returns an array of layout options registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_layouts() {
	$options = array(
		'left-sidebar' 	=> array(
			'value' => 'left-sidebar',
			'label' => esc_html__( 'Primary Sidebar, Content', 'rock-star-pro' ),
		),
		'right-sidebar' => array(
			'value' => 'right-sidebar',
			'label' => esc_html__( 'Content, Primary Sidebar', 'rock-star-pro' ),
		),
		'no-sidebar'	=> array(
			'value' => 'no-sidebar',
			'label' => esc_html__( 'No Sidebar ( Content Width )', 'rock-star-pro' ),
		),
		'no-sidebar-one-column' => array(
			'value' => 'no-sidebar-one-column',
			'label' => esc_html__( 'No Sidebar ( One Column )', 'rock-star-pro' ),
		),
		'no-sidebar-full-width' => array(
			'value' => 'no-sidebar-full-width',
			'label' => esc_html__( 'No Sidebar ( Full Width )', 'rock-star-pro' ),
		),
	);
	return apply_filters( 'rock_star_layouts', $options );
}


/**
 * Returns an array of content layout options registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_get_archive_content_layout() {
	$options = array(
		'excerpt-image-left' => array(
			'value' => 'excerpt-image-left',
			'label' => esc_html__( 'Excerpt Image Left', 'rock-star-pro' ),
		),
		'excerpt-image-right' => array(
			'value' => 'excerpt-image-right',
			'label' => esc_html__( 'Excerpt Image Right', 'rock-star-pro' ),
		),
		'excerpt-image-top' => array(
			'value' => 'excerpt-image-top',
			'label' => esc_html__( 'Excerpt Image Top', 'rock-star-pro' ),
		),
		'full-content' => array(
			'value' => 'full-content',
			'label' => esc_html__( 'Show Full Content (No Featured Image)', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_get_archive_content_layout', $options );
}


/**
 * Returns an array of feature header enable options
 *
 * @since Rock Star 1.0
 */
function rock_star_enable_featured_header_image_options() {
	$options = array(
		'homepage' 		=> array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Frontpage', 'rock-star-pro' ),
		),
		'exclude-home' 		=> array(
			'value'	=> 'exclude-home',
			'label' => esc_html__( 'Excluding Homepage', 'rock-star-pro' ),
		),
		'exclude-home-page-post' 	=> array(
			'value' => 'exclude-home-page-post',
			'label' => esc_html__( 'Excluding Homepage, Page/Post Featured Image', 'rock-star-pro' ),
		),
		'entire-site' 	=> array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'rock-star-pro' ),
		),
		'entire-site-page-post' 	=> array(
			'value' => 'entire-site-page-post',
			'label' => esc_html__( 'Entire Site, Page/Post Featured Image', 'rock-star-pro' ),
		),
		'pages-posts' 	=> array(
			'value' => 'pages-posts',
			'label' => esc_html__( 'Pages and Posts', 'rock-star-pro' ),
		),
		'disabled'		=> array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_enable_featured_header_image_options', $options );
}


/**
 * Returns an array of feature header image positions
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_header_image_position_options() {
	$options = array(
		'before_slider'		=> array(
			'value' => 'before-slider',
			'label' => esc_html__( 'Before Slider', 'rock-star-pro' ),
		),
		'after_slider'		=> array(
			'value' => 'after-slider',
			'label' => esc_html__( 'After Slider', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_featured_header_image_position_options', $options );
}


/**
 * Returns an array of feature image size
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_image_size_options() {
	$options = array(
		'full' 		=> array(
			'value'	=> 'full',
			'label' => esc_html__( 'Full Image', 'rock-star-pro' ),
		),
		'large' 	=> array(
			'value' => 'large',
			'label' => esc_html__( 'Large Image', 'rock-star-pro' ),
		),
		'slider'		=> array(
			'value' => 'slider',
			'label' => esc_html__( 'Slider Image', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_featured_image_size_options', $options );
}


/**
 * Returns an array of content and slider layout options registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_slider_content_options() {
	$options = array(
		'homepage' 		=> array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Frontpage', 'rock-star-pro' ),
		),
		'entire-site' 	=> array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'rock-star-pro' ),
		),
		'disabled'		=> array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_featured_slider_content_options', $options );
}


/**
 * Returns an array of news ticker types registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_news_ticker_types() {
	$options = array(
		'demo-news-ticker' => array(
			'value' => 'demo-news-ticker',
			'label' => esc_html__( 'Demo Content', 'rock-star-pro' ),
		),
		'post-news-ticker' => array(
			'value' => 'post-news-ticker',
			'label' => esc_html__( 'Post News Ticker', 'rock-star-pro' ),
		),
		'page-news-ticker' => array(
			'value' => 'page-news-ticker',
			'label' => esc_html__( 'Page News Ticker', 'rock-star-pro' ),
		),
		'category-news-ticker' => array(
			'value' => 'category-news-ticker',
			'label' => esc_html__( 'Category News Ticker', 'rock-star-pro' ),
		),
		'text-news-ticker' => array(
			'value' => 'text-news-ticker',
			'label' => esc_html__( 'Custom Text News Ticker', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_news_ticker_types', $options );
}


/**
 * Returns an array of news ticker positions registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_news_ticker_positions() {
	$options = array(
		'below-menu' => array(
			'value' => 'below-slider-header-image',
			'label' => esc_html__( 'Below Slider / Header Image', 'rock-star-pro' ),
		),
		'above-content' => array(
			'value' => 'above-content',
			'label' => esc_html__( 'Above Content', 'rock-star-pro' ),
		)
	);

	return apply_filters( 'rock_star_news_ticker_positions', $options );
}


/**
 * Returns an array of feature content types registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_content_types() {
	$options = array(
		'demo-featured-content' => array(
			'value' => 'demo-featured-content',
			'label' => esc_html__( 'Demo Featured Content', 'rock-star-pro' ),
		),
		'featured-post-content' => array(
			'value' => 'featured-post-content',
			'label' => esc_html__( 'Featured Post Content', 'rock-star-pro' ),
		),
		'featured-page-content' => array(
			'value' => 'featured-page-content',
			'label' => esc_html__( 'Featured Page Content', 'rock-star-pro' ),
		),
		'featured-category-content' => array(
			'value' => 'featured-category-content',
			'label' => esc_html__( 'Featured Category Content', 'rock-star-pro' ),
		),
		'featured-image-content' => array(
			'value' => 'featured-image-content',
			'label' => esc_html__( 'Featured Image Content', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_featured_content_types', $options );
}


/**
 * Returns an array of featured content options registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_content_layout_options() {
	$options = array(
		'one-column'   => array(
			'value'	=> 'one-column',
			'label' => esc_html__( '1 column', 'rock-star-pro' ),
		),
		'two-columns'   => array(
			'value'	=> 'two-columns',
			'label' => esc_html__( '2 columns', 'rock-star-pro' ),
		),
		'three-columns' => array(
			'value'	=> 'three-columns',
			'label' => esc_html__( '3 columns', 'rock-star-pro' ),
		),
		'four-columns' 	=> array(
			'value' => 'four-columns',
			'label' => esc_html__( '4 columns', 'rock-star-pro' ),
		),
		'five-columns' 	=> array(
			'value'	=> 'five-columns',
			'label' => esc_html__( '5 columns', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_featured_content_layout_options', $options );
}


/**
 * Returns an array of featured content show registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_content_show() {
	$options = array(
		'excerpt' 		=> array(
			'value'	=> 'excerpt',
			'label' => esc_html__( 'Show Excerpt', 'rock-star-pro' ),
		),
		'full-content' 	=> array(
			'value' => 'full-content',
			'label' => esc_html__( 'Show Full Content', 'rock-star-pro' ),
		),
		'hide-content' 	=> array(
			'value' => 'hide-content',
			'label' => esc_html__( 'Hide Content', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_featured_content_show', $options );
}


/**
 * Returns an array of featured content background image positions
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_content_background_display_positions() {
	$options = array(
		'top' => array(
			'value' => 'top',
			'label' => esc_html__( 'Top', 'rock-star-pro' ),
		),
		'bottom' => array(
			'value' => 'bottom',
			'label' => esc_html__( 'Bottom', 'rock-star-pro' ),
		),
	);
	return apply_filters( 'rock_star_featured_content_background_display_positions', $options );
}


/**
 * Returns an array of featured content background repeat options
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_content_background_repeat_options() {
	 $options = array(
		'no-repeat' => array(
			'value' => 'no-repeat',
			'label' => esc_html__( 'No repeat', 'rock-star-pro' ),
		),
		'tile' => array(
			'value' => 'repeat',
			'label' => esc_html__( 'Tile', 'rock-star-pro' ),
		)
	);
	return apply_filters( 'rock_star_featured_content_background_repeat_options', $options );
}


/**
 * Returns an array of featured content background attachment options
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_content_background_attachment_options() {
	$options = array(
		'scroll' => array(
			'value' => 'scroll',
			'label' => esc_html__( 'Scroll', 'rock-star-pro' ),
		),
		'fixed' => array(
			'value' => 'fixed',
			'label' => esc_html__( 'Fixed', 'rock-star-pro' ),
		),
	);
	return apply_filters( 'rock_star_featured_content_background_attachment_options', $options );
}


/**
 * Returns an array of feature slider types registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_slider_types() {
	$options = array(
		'demo-featured-slider' => array(
			'value' => 'demo-featured-slider',
			'label' => esc_html__( 'Demo Featured Slider', 'rock-star-pro' ),
		),
		'featured-post-slider' => array(
			'value' => 'featured-post-slider',
			'label' => esc_html__( 'Featured Post Slider', 'rock-star-pro' ),
		),
		'featured-page-slider' => array(
			'value' => 'featured-page-slider',
			'label' => esc_html__( 'Featured Page Slider', 'rock-star-pro' ),
		),
		'featured-category-slider' => array(
			'value' => 'featured-category-slider',
			'label' => esc_html__( 'Featured Category Slider', 'rock-star-pro' ),
		),
		'featured-image-slider' => array(
			'value' => 'featured-image-slider',
			'label' => esc_html__( 'Featured Image Slider', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_featured_slider_types', $options );
}


/**
 * Returns an array of feature slider transition effects
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_slide_transition_effects() {
	$options = array(
		'fade' 		=> array(
			'value'	=> 'fade',
			'label' => esc_html__( 'Fade', 'rock-star-pro' ),
		),
		'fadeout' 	=> array(
			'value'	=> 'fadeout',
			'label' => esc_html__( 'Fade Out', 'rock-star-pro' ),
		),
		'none' 		=> array(
			'value' => 'none',
			'label' => esc_html__( 'None', 'rock-star-pro' ),
		),
		'scrollHorz'=> array(
			'value' => 'scrollHorz',
			'label' => esc_html__( 'Scroll Horizontal', 'rock-star-pro' ),
		),
		'scrollVert'=> array(
			'value' => 'scrollVert',
			'label' => esc_html__( 'Scroll Vertical', 'rock-star-pro' ),
		),
		'flipHorz'	=> array(
			'value' => 'flipHorz',
			'label' => esc_html__( 'Flip Horizontal', 'rock-star-pro' ),
		),
		'flipVert'	=> array(
			'value' => 'flipVert',
			'label' => esc_html__( 'Flip Vertical', 'rock-star-pro' ),
		),
		'tileSlide'	=> array(
			'value' => 'tileSlide',
			'label' => esc_html__( 'Tile Slide', 'rock-star-pro' ),
		),
		'tileBlind'	=> array(
			'value' => 'tileBlind',
			'label' => esc_html__( 'Tile Blind', 'rock-star-pro' ),
		),
		'shuffle'	=> array(
			'value' => 'shuffle',
			'label' => esc_html__( 'Shuffle', 'rock-star-pro' ),
		)
	);

	return apply_filters( 'rock_star_featured_slide_transition_effects', $options );
}

/**
 * Returns an array of featured slider image loader options
 *
 * @since Rock Star 1.0
 */
function rock_star_featured_slider_image_loader() {
	$options = array(
		'true' => array(
			'value' 				=> 'true',
			'label' 				=> esc_html__( 'True', 'rock-star-pro' ),
		),
		'wait' => array(
			'value' 				=> 'wait',
			'label' 				=> esc_html__( 'Wait', 'rock-star-pro' ),
		),
		'false' => array(
			'value' 				=> 'false',
			'label' 				=> esc_html__( 'False', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_featured_slider_image_loader', $options );
}


/**
 * Returns an array of pagination types registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_get_pagination_types() {
	$options = array(
		'default' => array(
			'value' => 'default',
			'label' => esc_html__( 'Default(Older Posts/Newer Posts)', 'rock-star-pro' ),
		),
		'numeric' => array(
			'value' => 'numeric',
			'label' => esc_html__( 'Numeric', 'rock-star-pro' ),
		),
		'infinite-scroll-click' => array(
			'value' => 'infinite-scroll-click',
			'label' => esc_html__( 'Infinite Scroll (Click)', 'rock-star-pro' ),
		),
		'infinite-scroll-scroll' => array(
			'value' => 'infinite-scroll-scroll',
			'label' => esc_html__( 'Infinite Scroll (Scroll)', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_get_pagination_types', $options );
}


/**
 * Returns an array of content featured image size.
 *
 * @since Rock Star 1.0
 */
function rock_star_single_post_image_size_options() {
	$options = array(
		'large' => array(
			'value' => 'large',
			'label' => esc_html__( 'Large', 'rock-star-pro' ),
		),
		'full-size' => array(
			'value' => 'full-size',
			'label' => esc_html__( 'Full size', 'rock-star-pro' ),
		),
		'slider-image-size' => array(
			'value' => 'slider-image-size',
			'label' => esc_html__( 'Slider Image Size', 'rock-star-pro' ),
		),
		'featured' => array(
			'value' => 'featured',
			'label' => esc_html__( 'Featured Image Size', 'rock-star-pro' ),
		),
		'disabled' => array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'rock-star-pro' ),
		),
	);
	return apply_filters( 'rock_star_single_post_image_size_options', $options );
}


/**
 * Returns an array of comment options for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_comment_options() {
	$comment_options = array(
		'use-wordpress-setting' => array(
			'value' => 'use-wordpress-setting',
			'label' => esc_html__( 'Use WordPress Setting', 'rock-star-pro' ),
		),
		'disable-in-pages' => array(
			'value' => 'disable-in-pages',
			'label' => esc_html__( 'Disable in Pages', 'rock-star-pro' ),
		),
		'disable-completely' => array(
			'value' => 'disable-completely',
			'label' => esc_html__( 'Disable Completely', 'rock-star-pro' ),
		),
	);

	return apply_filters( 'rock_star_comment_options', $comment_options );
}


/**
 * Returns an array of avaliable fonts registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_avaliable_fonts() {
	$options = array(
		'arial-black' => array(
			'value' => 'arial-black',
			'label' => '"Arial Black", Gadget, sans-serif',
		),
		'allan' => array(
			'value' => 'allan',
			'label' => '"Allan", sans-serif',
		),
		'allerta' => array(
			'value' => 'allerta',
			'label' => '"Allerta", sans-serif',
		),
		'amaranth' => array(
			'value' => 'amaranth',
			'label' => '"Amaranth", sans-serif',
		),
		'arial' => array(
			'value' => 'arial',
			'label' => 'Arial, Helvetica, sans-serif',
		),
		'bitter' => array(
			'value' => 'bitter',
			'label' => '"Bitter", sans-serif',
		),
		'cabin' => array(
			'value' => 'cabin',
			'label' => '"Cabin", sans-serif',
		),
		'cantarell' => array(
			'value' => 'cantarell',
			'label' => '"Cantarell", sans-serif',
		),
		'century-gothic' => array(
			'value' => 'century-gothic',
			'label' => '"Century Gothic", sans-serif',
		),
		'courier-new' => array(
			'value' => 'courier-new',
			'label' => '"Courier New", Courier, monospace',
		),
		'courgette' => array(
			'value' => 'courgette',
			'label' => '"Courgette", cursive',
		),
		'crimson-text' => array(
			'value' => 'crimson-text',
			'label' => '"Crimson Text", sans-serif',
		),
		'cuprum' => array(
			'value' => 'cuprum',
			'label' => '"Cuprum", sans-serif',
		),
		'dancing-script' => array(
			'value' => 'dancing-script',
			'label' => '"Dancing Script", sans-serif',
		),
		'droid-sans' => array(
			'value' => 'droid-sans',
			'label' => '"Droid Sans", sans-serif',
		),
		'droid-serif' => array(
			'value' => 'droid-serif',
			'label' => '"Droid Serif", sans-serif',
		),
		'exo' => array(
			'value' => 'exo',
			'label' => '"Exo", sans-serif',
		),
		'exo-2' => array(
			'value' => 'exo-2',
			'label' => '"Exo 2", sans-serif',
		),
		'georgia' => array(
			'value' => 'georgia',
			'label' => 'Georgia, "Times New Roman", Times, serif',
		),
		'helvetica' => array(
			'value' => 'helvetica',
			'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
		),
		'helvetica-neue' => array(
			'value' => 'helvetica-neue',
			'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
		),
		'istok-web' => array(
			'value' => 'istok-web',
			'label' => '"Istok Web", sans-serif',
		),
		'impact' => array(
			'value' => 'impact',
			'label' => 'Impact, Charcoal, sans-serif',
		),
		'josefin-sans' => array(
			'value' => 'josefin-sans',
			'label' => '"Josefin Sans", sans-serif',
		),
		'lato' => array(
			'value' => 'lato',
			'label' => '"Lato", sans-serif',
		),
		'libre-baskerville' => array(
			'value' => 'libre-baskerville',
			'label' => '"Libre Baskerville",serif'
		),
		'lucida-sans-unicode' => array(
			'value' => 'lucida-sans-unicode',
			'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		),
		'lucida-grande' => array(
			'value' => 'lucida-grande',
			'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
		),
		'lobster' => array(
			'value' => 'lobster',
			'label' => '"Lobster", sans-serif',
		),
		'lora' => array(
			'value' => 'lora',
			'label' => '"Lora", serif',
		),
		'monaco' => array(
			'value' => 'monaco',
			'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
		),
		'merriweather' => array(
			'value' => 'merriweather',
			'label' => '"Merriweather", sans-serif',
		),
		'montserrat' => array(
			'value' => 'montserrat',
			'label' => '"Montserrat", sans-serif',
		),
		'nobile' => array(
			'value' => 'nobile',
			'label' => '"Nobile", sans-serif',
		),
		'noto-serif' => array(
			'value' => 'noto-serif',
			'label' => '"Noto Serif", serif',
		),
		'neuton' => array(
			'value' => 'neuton',
			'label' => '"Neuton", serif',
		),
		'open-sans' => array(
			'value' => 'open-sans',
			'label' => '"Open Sans", sans-serif',
		),
		'oswald' => array(
			'value' => 'oswald',
			'label' => '"Oswald", sans-serif',
		),
		'palatino' => array(
			'value' => 'palatino',
			'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
		),
		'patua-one' => array(
			'value' => 'patua-one',
			'label' => '"Patua One", sans-serif',
		),
		'playfair-display' => array(
			'value' => 'playfair-display',
			'label' => '"Playfair Display", sans-serif',
		),
		'pt-sans' => array(
			'value' => 'pt-sans',
			'label' => '"PT Sans", sans-serif',
		),
		'pt-serif' => array(
			'value' => 'pt-serif',
			'label' => '"PT Serif", serif',
		),
		'quattrocento' => array(
			'value' => 'quattrocento',
			'label' => '"Quattrocento", serif',
		),
		'quattrocento-sans' => array(
			'value' => 'quattrocento-sans',
			'label' => '"Quattrocento Sans", sans-serif',
		),
		'roboto' => array(
			'value' => 'roboto',
			'label' => '"Roboto", sans-serif',
		),
		'roboto-slab' => array(
			'value' => 'roboto-slab',
			'label' => '"Roboto Slab", serif',
		),
		'sans-serif' => array(
			'value' => 'sans-serif',
			'label' => 'Sans Serif, Arial',
		),
		'source-sans-pro' => array(
			'value' => 'source-sans-pro',
			'label' => '"Source Sans Pro", sans-serif',
		),
		'tahoma' => array(
			'value' => 'tahoma',
			'label' => 'Tahoma, Geneva, sans-serif',
		),
		'trebuchet-ms' => array(
			'value' => 'trebuchet-ms',
			'label' => '"Trebuchet MS", "Helvetica", sans-serif',
		),
		'times-new-roman' => array(
			'value' => 'times-new-roman',
			'label' => '"Times New Roman", Times, serif',
		),
		'ubuntu' => array(
			'value' => 'ubuntu',
			'label' => '"Ubuntu", sans-serif',
		),
		'varela' => array(
			'value' => 'varela',
			'label' => '"Varela", sans-serif',
		),
		'verdana' => array(
			'value' => 'verdana',
			'label' => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz' => array(
			'value' => 'yanone-kaffeesatz',
			'label' => '"Yanone Kaffeesatz", sans-serif',
		),
	);

	return apply_filters( 'rock_star_avaliable_fonts', $options );
}


/**
 * Returns list of social icons currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_social_icons_list() {
	$options = array(
		'facebook_link'		=> array(
			'genericon_class' 	=> 'facebook-alt',
			'label' 			=> esc_html__( 'Facebook', 'rock-star-pro' )
			),
		'twitter_link'		=> array(
			'genericon_class' 	=> 'twitter',
			'label' 			=> esc_html__( 'Twitter', 'rock-star-pro' )
			),
		'googleplus_link'	=> array(
			'genericon_class' 	=> 'googleplus',
			'label' 			=> esc_html__( 'Googleplus', 'rock-star-pro' )
			),
		'email_link'		=> array(
			'genericon_class' 	=> 'mail',
			'label' 			=> esc_html__( 'Email', 'rock-star-pro' )
			),
		'feed_link'			=> array(
			'genericon_class' 	=> 'feed',
			'label' 			=> esc_html__( 'Feed', 'rock-star-pro' )
			),
		'wordpress_link'	=> array(
			'genericon_class' 	=> 'wordpress',
			'label' 			=> esc_html__( 'WordPress', 'rock-star-pro' )
			),
		'github_link'		=> array(
			'genericon_class' 	=> 'github',
			'label' 			=> esc_html__( 'GitHub', 'rock-star-pro' )
			),
		'linkedin_link'		=> array(
			'genericon_class' 	=> 'linkedin',
			'label' 			=> esc_html__( 'LinkedIn', 'rock-star-pro' )
			),
		'pinterest_link'	=> array(
			'genericon_class' 	=> 'pinterest',
			'label' 			=> esc_html__( 'Pinterest', 'rock-star-pro' )
			),
		'flickr_link'		=> array(
			'genericon_class' 	=> 'flickr',
			'label' 			=> esc_html__( 'Flickr', 'rock-star-pro' )
			),
		'vimeo_link'		=> array(
			'genericon_class' 	=> 'vimeo',
			'label' 			=> esc_html__( 'Vimeo', 'rock-star-pro' )
			),
		'youtube_link'		=> array(
			'genericon_class' 	=> 'youtube',
			'label' 			=> esc_html__( 'YouTube', 'rock-star-pro' )
			),
		'tumblr_link'		=> array(
			'genericon_class' 	=> 'tumblr',
			'label' 			=> esc_html__( 'Tumblr', 'rock-star-pro' )
			),
		'instagram_link'	=> array(
			'genericon_class' 	=> 'instagram',
			'label' 			=> esc_html__( 'Instagram', 'rock-star-pro' )
			),
		'polldaddy_link'	=> array(
			'genericon_class' 	=> 'polldaddy',
			'label' 			=> esc_html__( 'PollDaddy', 'rock-star-pro' )
			),
		'codepen_link'		=> array(
			'genericon_class' 	=> 'codepen',
			'label' 			=> esc_html__( 'CodePen', 'rock-star-pro' )
			),
		'path_link'			=> array(
			'genericon_class' 	=> 'path',
			'label' 			=> esc_html__( 'Path', 'rock-star-pro' )
			),
		'dribbble_link'		=> array(
			'genericon_class' 	=> 'dribbble',
			'label' 			=> esc_html__( 'Dribbble', 'rock-star-pro' )
			),
		'skype_link'		=> array(
			'genericon_class' 	=> 'skype',
			'label' 			=> esc_html__( 'Skype', 'rock-star-pro' )
			),
		'digg_link'			=> array(
			'genericon_class' 	=> 'digg',
			'label' 			=> esc_html__( 'Digg', 'rock-star-pro' )
			),
		'reddit_link'		=> array(
			'genericon_class' 	=> 'reddit',
			'label' 			=> esc_html__( 'Reddit', 'rock-star-pro' )
			),
		'stumbleupon_link'	=> array(
			'genericon_class' 	=> 'stumbleupon',
			'label' 			=> esc_html__( 'Stumbleupon', 'rock-star-pro' )
			),
		'pocket_link'		=> array(
			'genericon_class' 	=> 'pocket',
			'label' 			=> esc_html__( 'Pocket', 'rock-star-pro' ),
			),
		'dropbox_link'		=> array(
			'genericon_class' 	=> 'dropbox',
			'label' 			=> esc_html__( 'DropBox', 'rock-star-pro' ),
			),
		'spotify_link'		=> array(
			'genericon_class' 	=> 'spotify',
			'label' 			=> esc_html__( 'Spotify', 'rock-star-pro' ),
			),
		'foursquare_link'	=> array(
			'genericon_class' 	=> 'foursquare',
			'label' 			=> esc_html__( 'Foursquare', 'rock-star-pro' ),
			),
		'twitch_link'		=> array(
			'genericon_class' 	=> 'twitch',
			'label' 			=> esc_html__( 'Twitch', 'rock-star-pro' ),
			),
		'website_link'		=> array(
			'genericon_class' 	=> 'website',
			'label' 			=> esc_html__( 'Website', 'rock-star-pro' ),
			),
		'phone_link'		=> array(
			'genericon_class' 	=> 'phone',
			'label' 			=> esc_html__( 'Phone', 'rock-star-pro' ),
			),
		'handset_link'		=> array(
			'genericon_class' 	=> 'handset',
			'label' 			=> esc_html__( 'Handset', 'rock-star-pro' ),
			),
		'cart_link'			=> array(
			'genericon_class' 	=> 'cart',
			'label' 			=> esc_html__( 'Cart', 'rock-star-pro' ),
			),
		'cloud_link'		=> array(
			'genericon_class' 	=> 'cloud',
			'label' 			=> esc_html__( 'Cloud', 'rock-star-pro' ),
			),
		'link_link'		=> array(
			'genericon_class' 	=> 'link',
			'label' 			=> esc_html__( 'Link', 'rock-star-pro' ),
			),
	);

	return apply_filters( 'rock_star_social_icons_list', $options );
}


/**
 * Returns list of basic color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_basic_color_options() {
	$options =	array(
		'text_color' 		=> __( 'Text Color', 'rock-star-pro' ),
		'link_color' 		=> __( 'Link Color', 'rock-star-pro' ),
		'link_hover_color'	=> __( 'Link Hover Color', 'rock-star-pro' ),
	);

	return apply_filters( 'rock_star_get_basic_color_options', $options );
}


/**
 * Returns list of content color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_content_color_options() {
	$options =	array(
		'content_wrapper_background_color' 	=> esc_html__( 'Content Wrapper Background Color', 'rock-star-pro' ),
		'content_background_color'			=> esc_html__( 'Content Background Color', 'rock-star-pro' ),
		'content_title_color' 				=> esc_html__( 'Content Title Color', 'rock-star-pro' ),
		'content_title_hover_color' 		=> esc_html__( 'Content Title Hover Color', 'rock-star-pro' ),
		'content_meta_color' 				=> esc_html__( 'Content Meta Color', 'rock-star-pro' ),
		'content_meta_hover_color' 			=> esc_html__( 'Content Meta Hover Color', 'rock-star-pro' ),
		'sticky_post_label_background_color'=> esc_html__( 'Sticky Post Label Background Color', 'rock-star-pro' ),
		'sticky_post_label_text_color' 		=> esc_html__( 'Sticky Post Label Text Color', 'rock-star-pro' ),
	);

	return apply_filters( 'rock_star_get_content_color_options', $options );
}


/**
 * Returns list of header color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_header_color_options() {
	$options =	array(
		'header_background_color' 	=> esc_html__( 'Header Background color', 'rock-star-pro' ),
		'site_title_hover_color' 	=> esc_html__( 'Site Title Hover Color', 'rock-star-pro' ),
		'tagline_color' 			=> esc_html__( 'Tagline Color', 'rock-star-pro' )
	);

	return apply_filters( 'rock_star_get_header_color_options', $options );
}


/**
 * Returns list of sidebar color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_sidebar_color_options() {
	$options = array(
		'sidebar_background_color'   => esc_html__( 'Sidebar Background Color', 'rock-star-pro' ),
		'sidebar_widget_title_color' => esc_html__( 'Sidebar Widget Title Color', 'rock-star-pro' ),
		'sidebar_widget_text_color'  => esc_html__( 'Sidebar Widget Text Color', 'rock-star-pro' ),
		'sidebar_widget_link_color'  => esc_html__( 'Sidebar Widget Link Color', 'rock-star-pro' ),
	);
	return apply_filters( 'rock_star_get_sidebar_color_options', $options );
}


/**
 * Returns list of pagination color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_pagination_color_options() {
	$options = array(
		'pagination_background_color'                    => esc_html__( 'Background Color', 'rock-star-pro' ),
		'pagination_hover_background_color'              => esc_html__( 'Hover Background Color', 'rock-star-pro' ),
		'pagination_text_color'                          => esc_html__( 'Text Color', 'rock-star-pro' ),
		'pagination_link_color'                          => esc_html__( 'Link Color', 'rock-star-pro' ),
		'pagination_border_color'                        => esc_html__( 'Border Color', 'rock-star-pro' ),
		'pagination_hover_active_color'                  => esc_html__( 'Hover/Active Color', 'rock-star-pro' ),
		'pagination_hover_active_border_color'           => esc_html__( 'Hover/Active Border Color', 'rock-star-pro' ),
	);
	return apply_filters( 'rock_star_get_pagination_color_options', $options );
}


/**
 * Returns list of footer color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_footer_color_options() {
	$options =	array(
		'footer_background_color' 				=> esc_html__( 'Background Color', 'rock-star-pro' ),
		'footer_text_color' 					=> esc_html__( 'Text Color', 'rock-star-pro' ),
		'footer_link_color' 					=> esc_html__( 'Link Color', 'rock-star-pro' ),
		'footer_link_hover_color' 				=> esc_html__( 'Link Hover Color', 'rock-star-pro' ),
		'footer_sidebar_area_background_color' 	=> esc_html__( 'Sidebar Area Background Color', 'rock-star-pro' ),
		'footer_widget_text_color'				=> esc_html__( 'Widget Text Color', 'rock-star-pro' ),
		'footer_widget_background_color' 		=> esc_html__( 'Widget Background Color', 'rock-star-pro' ),
		'footer_widget_title_color'				=> esc_html__( 'Widget Title Color', 'rock-star-pro' ),
		'footer_widget_link_color'				=> esc_html__( 'Widget Link Color', 'rock-star-pro' ),
		'footer_widget_link_hover_color'		=> esc_html__( 'Widget Link Hover Color', 'rock-star-pro' ),

	);

	return apply_filters( 'rock_star_get_footer_color_options', $options );
}


/**
 * Returns list of scrollup color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_scrollup_color_options() {
	$options =	array(
		'scrollup_background_color'			=> esc_html__( 'Background Color', 'rock-star-pro' ),
		'scrollup_hover_background_color'	=> esc_html__( 'Hover Background Color', 'rock-star-pro' ),
		'scrollup_text_color'				=> esc_html__( 'Text Color', 'rock-star-pro' ),
		'scrollup_hover_text_color'			=> esc_html__( 'Hover Text Color', 'rock-star-pro' ),
	);

	return apply_filters( 'rock_star_get_scrollup_color_options', $options );
}


/**
 * Returns list of featured_content color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_featured_content_color_options() {
	$options = array(
		'featured_content_background_color'	=> esc_html__( 'Background Color', 'rock-star-pro' ),
		'featured_content_title_color'		=> esc_html__( 'Title Color', 'rock-star-pro' ),
		'featured_content_title_hover_color'=> esc_html__( 'Title Hover Color', 'rock-star-pro' ),
		'featured_content_text_color'		=> esc_html__( 'Text Color', 'rock-star-pro' ),
		'featured_content_link_color'		=> esc_html__( 'Link Color', 'rock-star-pro' ),
		'featured_content_link_hover_color'	=> esc_html__( 'Link Hover Color', 'rock-star-pro' ),
	);

	return apply_filters( 'rock_star_get_featured_content_color_options', $options );
}


/**
 * Returns list of news ticker color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_news_ticker_color_options() {
	$options = array(
		'news_ticker_background_color'	=> esc_html__( 'Background Color', 'rock-star-pro' ),
		'news_ticker_label_color'		=> esc_html__( 'Label Color', 'rock-star-pro' ),
		'news_ticker_label_border_color'=> esc_html__( 'Label Border Color', 'rock-star-pro' ),
		'news_ticker_title_color'		=> esc_html__( 'Title Color', 'rock-star-pro' ),
		'news_ticker_title_hover_color'=> esc_html__( 'Title Hover Color', 'rock-star-pro' ),
	);

	return apply_filters( 'rock_star_get_news_ticker_color_options', $options );
}


/**
 * Returns list of slider color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_slider_color_options() {
	$options =	array(
		'slider_content_background_color'       => esc_html__( 'Content Background Color', 'rock-star-pro' ),
		'slider_text_color'                     => esc_html__( 'Text Color', 'rock-star-pro' ),
		'slider_link_color'                     => esc_html__( 'Link Color', 'rock-star-pro' ),
		'slider_link_hover_color'               => esc_html__( 'Link Hover Color', 'rock-star-pro' ),
		'slider_title_color'                    => esc_html__( 'Title Color', 'rock-star-pro' ),
		'slider_title_hover_color'              => esc_html__( 'Title Hover Color', 'rock-star-pro' ),
		'slider_button_background_color'        => esc_html__( 'Button Background Color', 'rock-star-pro' ),
		'slider_button_border_color'            => esc_html__( 'Button Border Color', 'rock-star-pro' ),
		'slider_button_text_color'              => esc_html__( 'Button Text Color', 'rock-star-pro' ),
		'slider_button_hover_background_color'  => esc_html__( 'Button Hover Background Color', 'rock-star-pro' ),
		'slider_button_hover_border_color'      => esc_html__( 'Button Hover Border Color', 'rock-star-pro' ),
		'slider_button_hover_text_color'        => esc_html__( 'Button Hover Text Color', 'rock-star-pro' ),
		'slider_control_background_color'       => esc_html__( 'Control Background Color', 'rock-star-pro' ),
		'slider_control_text_color'             => esc_html__( 'Control Text Color', 'rock-star-pro' ),
		'slider_control_hover_background_color' => esc_html__( 'Control Hover Background Color', 'rock-star-pro' ),
		'slider_control_hover_text_color'       => esc_html__( 'Control Hover Text Color', 'rock-star-pro' ),
		'slider_pager_color'                    => esc_html__( 'Pager Color', 'rock-star-pro' ),
		'slider_pager_hover_color'              => esc_html__( 'Pager Hover Color', 'rock-star-pro' ),
	);

	return apply_filters( 'rock_star_get_slider_color_options', $options );
}


/**
 * Returns list of menu color options currently supported
 *
 * @since Rock Star 1.0
*/
function rock_star_get_menu_color_options() {
	$options =	array(
		'menu_background_color'				=> esc_html__( 'Background color', 'rock-star-pro' ),
		'menu_color'						=> esc_html__( 'Color', 'rock-star-pro' ),
		'hover_active_background_color'		=> esc_html__( 'Hover Active Background Color', 'rock-star-pro' ),
		'hover_active_text_color'			=> esc_html__( 'Hover Active Text Color', 'rock-star-pro' ),
		'sub_menu_background_color'			=> esc_html__( 'Sub Menu Background Color', 'rock-star-pro' ),
		'sub_menu_text_color'				=> esc_html__( 'Sub Menu Text Color', 'rock-star-pro' ),
		'sub_menu_hover_background_color'	=> esc_html__( 'Sub Menu Hover Background Color', 'rock-star-pro' ),
		'sub_menu_hover_text_color'			=> esc_html__( 'Sub Menu Hover Text Color', 'rock-star-pro' ),
	);
	return apply_filters( 'rock_star_get_menu_color_options', $options );
}

/**
 * Returns an array of metabox layout options registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_metabox_layouts() {
	$options = array(
		'default' 	=> array(
			'id' 	=> 'rock-star-layout-option',
			'value' => 'default',
			'label' => esc_html__( 'Default', 'rock-star-pro' ),
		),
		'left-sidebar' 	=> array(
			'id' 	=> 'rock-star-layout-option',
			'value' => 'left-sidebar',
			'label' => esc_html__( 'Primary Sidebar, Content', 'rock-star-pro' ),
		),
		'right-sidebar' => array(
			'id' 	=> 'rock-star-layout-option',
			'value' => 'right-sidebar',
			'label' => esc_html__( 'Content, Primary Sidebar', 'rock-star-pro' ),
		),
		'no-sidebar'	=> array(
			'id' 	=> 'rock-star-layout-option',
			'value' => 'no-sidebar',
			'label' => esc_html__( 'No Sidebar ( Content Width )', 'rock-star-pro' ),
		),
		'no-sidebar-one-column' => array(
			'id' 	=> 'rock-star-layout-option',
			'value' => 'no-sidebar-one-column',
			'label' => esc_html__( 'No Sidebar ( One Column )', 'rock-star-pro' ),
		),
		'no-sidebar-full-width' => array(
			'id' 	=> 'rock-star-layout-option',
			'value' => 'no-sidebar-full-width',
			'label' => esc_html__( 'No Sidebar ( Full Width )', 'rock-star-pro' ),
		),
	);
	return apply_filters( 'rock_star_layouts', $options );
}

/**
 * Returns an array of metabox header featured image options registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_metabox_header_featured_image_options() {
	$options = array(
		'default' => array(
			'id'		=> 'rock-star-header-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default', 'rock-star-pro' ),
		),
		'enable' => array(
			'id'		=> 'rock-star-header-image',
			'value' 	=> 'enable',
			'label' 	=> esc_html__( 'Enable', 'rock-star-pro' ),
		),
		'disable' => array(
			'id'		=> 'rock-star-header-image',
			'value' 	=> 'disable',
			'label' 	=> esc_html__( 'Disable', 'rock-star-pro' )
		)
	);
	return apply_filters( 'header_featured_image_options', $options );
}


/**
 * Returns an array of metabox sidebar options registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_metabox_sidebar_options() {
	$options = array(
		'main-sidebar' => array(
			'id'		=> 'rock-star-sidebar-options',
			'value' 	=> 'default-sidebar',
			'label' 	=> esc_html__( 'Default Sidebar', 'rock-star-pro' )
		),
		'optional-sidebar-one' => array(
			'id' 	=> 'rock-star-sidebar-options',
			'value' => 'optional-sidebar-one',
			'label' => esc_html__( 'Optional Sidebar One', 'rock-star-pro' )
		),
		'optional-sidebar-two' => array(
			'id' 	=> 'rock-star-sidebar-options',
			'value' => 'optional-sidebar-two',
			'label' => esc_html__( 'Optional Sidebar Two', 'rock-star-pro' )
		),
		'optional-sidebar-three' => array(
			'id' 	=> 'rock-star-sidebar-options',
			'value' => 'optional-sidebar-three',
			'label' => esc_html__( 'Optional Sidebar three', 'rock-star-pro' )
		)
	);
	return apply_filters( 'sidebar_options', $options );
}


/**
 * Returns an array of metabox featured image options registered for Rock Star.
 *
 * @since Rock Star 1.0
 */
function rock_star_metabox_featured_image_options() {
	$options = array(
		'default' => array(
			'id'		=> 'rock-star-featured-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default', 'rock-star-pro' ),
		),
		'featured' => array(
			'id'		=> 'rock-star-featured-image',
			'value' 	=> 'featured',
			'label' 	=> esc_html__( 'Featured Image', 'rock-star-pro' )
		),
		'full' => array(
			'id' => 'rock-star-featured-image',
			'value' => 'full',
			'label' => esc_html__( 'Full Image', 'rock-star-pro' )
		),
		'slider' => array(
			'id' => 'rock-star-featured-image',
			'value' => 'slider',
			'label' => esc_html__( 'Slider Image', 'rock-star-pro' )
		),
		'disable' => array(
			'id' => 'rock-star-featured-image',
			'value' => 'disable',
			'label' => esc_html__( 'Disable Image', 'rock-star-pro' )
		)
	);
	return apply_filters( 'featured_image_options', $options );
}

/**
 * Returns an array of Color Scheme.
 *
 * @since Rock Star 1.0
 */
function rock_star_color_scheme_options() {
	$options = array(
		'light' => array(
			'value' => 'light',
			'label' => esc_html__( 'Light', 'rock-star-pro' ),
		),
		'dark' => array(
			'value' => 'dark',
			'label' => esc_html__( 'Dark', 'rock-star-pro' ),
		),
	);
	return apply_filters( 'color_scheme_options', $options );
}


/**
 * Returns the default options for Rock Star dark theme.
 *
 * @since Rock Star 1.0
 */
function rock_star_default_light_color_options() {
	$options = array(
		//Basic Color Options
		'background_color'                      => '#ffffff',
		'text_color'                            => '#404040',
		'link_color'                            => '#e8554e',
		'link_hover_color'                      => '#404040',

		//Header Color Options
		'header_textcolor'                      => '#ffffff',
		'header_background_color'               => '#000000',
		'site_title_hover_color'                => '#e8554e',
		'tagline_color'                         => '#ffffff',

		//Content Color Options
		'content_wrapper_background_color'      => '',
		'content_background_color'              => '',
		'content_title_color'                   => '#404040',
		'content_title_hover_color'             => '#e8554e',
		'content_meta_color'                    => '#666666',
		'content_meta_hover_color'              => '#e8554e',
		'sticky_post_label_background_color'    => '#000000',
		'sticky_post_label_text_color'          => '#ffffff',

		//Sidebar Color Options
		'sidebar_background_color'              => '',
		'sidebar_widget_title_color'            => '#404040',
		'sidebar_widget_text_color'             => '#404040',
		'sidebar_widget_link_color'             => '#e8554e',
		'sidebar_widget_link_hover_color'       => '#404040',

		//Pagination Color Options
		'pagination_background_color'           => '',
		'pagination_hover_background_color'     => '#e8554e',
		'pagination_text_color'                 => '#404040',
		'pagination_link_color'                 => '#e8554e',
		'pagination_border_color'               => '#e8554e',
		'pagination_hover_active_color'         => '#ffffff',
		'pagination_hover_active_border_color'  => '#e8554e',

		//Footer Color Options
		'footer_background_color'               => '#000000',
		'footer_text_color'                     => '#dddddd',
		'footer_link_color'                     => '#ffffff',
		'footer_link_hover_color'               => '#dddddd',
		'footer_sidebar_area_background_color'  => '',
		'footer_widget_background_color'        => '',
		'footer_widget_title_color'             => '#404040',
		'footer_widget_text_color'              => '#404040',
		'footer_widget_link_color'              => '#e8554e',
		'footer_widget_link_hover_color'        => '#404040',

		//Scrollup Color Options
		'scrollup_background_color'             => '',
		'scrollup_hover_background_color'       => '#e8554e',
		'scrollup_text_color'                   => '#e8554e',
		'scrollup_hover_text_color'             => '#ffffff',

		//Featured Content Color Options
		'featured_content_background_color'     => '',
		'featured_content_title_color'          => '#404040',
		'featured_content_title_hover_color'    => '#e8554e',
		'featured_content_text_color'           => '#404040',
		'featured_content_link_color'           => '#e8554e',
		'featured_content_link_hover_color'     => '#404040',

		//News Ticker Color Options
		'news_ticker_background_color'          => '#dddddd',
		'news_ticker_label_color'               => '#e8554e',
		'news_ticker_label_border_color'        => '#ffffff',
		'news_ticker_title_color'               => '#404040',
		'news_ticker_title_hover_color'         => '#e8554e',

		//Slider Color Options
		'slider_content_background_color'       => '#000000',
		'slider_text_color'                     => '#ffffff',
		'slider_link_color'                     => '#e8554e',
		'slider_link_hover_color'               => '#ffffff',
		'slider_title_color'                    => '#ffffff',
		'slider_title_hover_color'              => '#dddddd',
		'slider_button_background_color'        => '',
		'slider_button_border_color'            => '#ffffff',
		'slider_button_text_color'              => '#ffffff',
		'slider_button_hover_background_color'  => '#e8554e',
		'slider_button_hover_border_color'      => '#e8554e',
		'slider_button_hover_text_color'        => '#ffffff',
		'slider_control_background_color'       => '#000000',
		'slider_control_text_color'             => '#ffffff',
		'slider_control_hover_background_color' => '#e8554e',
		'slider_control_hover_text_color'       => '#ffffff',
		'slider_pager_color'                    => '#ffffff',
		'slider_pager_hover_color'              => '#e8554e',

		//Primary Menu Color Options
		'menu_background_color'                 => '',
		'menu_color'                            => '#ffffff',
		'hover_active_background_color'         => '',
		'hover_active_text_color'               => '#e8554e',
		'sub_menu_background_color'             => '#444444',
		'sub_menu_text_color'                   => '#ffffff',
		'sub_menu_hover_background_color'       => '#444444',
		'sub_menu_hover_text_color'             => '#e8554e',
	);

	return apply_filters( 'rock_star_default_light_color_options', $options );
}


/**
 * Checks if there are options already present from Rock Star free version and adds it to the Rock Star Pro theme options
 *
 * @since Rock Star Pro 1.0
 * @hook after_theme_switch
 */
function rock_star_setup_options() {
	//Perform action only if theme_mods_theme_mods_rock-star-pro does not exist
	if ( !get_option( 'theme_mods_rock-star-pro' ) ) {
		//Perform action only if theme_mods_rock-star free version exists
		if ( $free_options = get_option ( 'theme_mods_rock-star' ) ) {
			update_option('theme_mods_rock-star-pro', $free_options );
		}
	}
}
add_action( 'after_switch_theme', 'rock_star_setup_options' );
