<?php
/**
 * Featured Embed Widget
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Makes a custom Widget for Displaying Embed Codes
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */
class rock_star_audio_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'title'        => '',
			'items_number' => 3,
			'background-image' => '',
			'link'         => '',
			'link_text'    => ''
		);

		$widget_ops = array(
			'classname'   => 'ct-audio ctaudio',
			'description' => esc_html__( 'Use this widget to add Audio', 'rock-star-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-audio',
		);

		parent::__construct(
			'ct-audio', // Base ID
			esc_html__( 'CT: Audio', 'rock-star-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, code, alt
	 * $instance Current settings
	 */
	function form($instance) {

		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>
		<p class="ct-description">
			<span>* Audio Widget is not suitable for primary sidebars.</span><br />
			<span>* Please use only one instance of this widget at a time.</span>
		</p>
        <p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'items_number' ); ?>"><?php esc_html_e( 'No. of Items', 'rock-star-pro' ); ?>:</label>
			<input type="number" id="<?php echo $this->get_field_id( 'items_number' ); ?>" name="<?php echo $this->get_field_name( 'items_number' ); ?>" value="<?php echo absint( $instance['items_number'] ); ?>" class="small-text" min="1" />
			<br>
			<span class="ct-description"><?php esc_html_e( 'Please save the widget once No. of items is changed to reflect the changes', 'rock-star-pro' ); ?></span>
		</p>

		<p>
            <label for="<?php echo $this->get_field_id( 'background-image' ); ?>"><?php esc_html_e( 'Background Image Url:','rock-star-pro'); ?></label>
            <br>
        	<input type="text" class="ct-upload" name="<?php echo $this->get_field_name( 'background-image' ); ?>" value="<?php echo esc_attr( $instance['background-image'] ); ?>" id="<?php echo $this->get_field_id( 'background-image' ); ?>" />
        	<button class="upload-media-button button button-primary"><?php esc_html_e( 'Upload', 'rock-star-pro' ); ?></button>
        </p>

		<?php for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) { ?>
		<div class="ct-image-box">
			<?php
				$audio_title     =  isset( $instance['audio_title' . '_' .  $i] ) ? $instance['audio_title' . '_' .  $i] : '';
				$audio_file      =  isset( $instance['audio_file' . '_' .  $i] ) ? $instance['audio_file' . '_' .  $i] : '';
				$audio_album     =  isset( $instance['audio_album' . '_' .  $i] ) ? $instance['audio_album' . '_' .  $i] : '';
				$album_art       =  isset( $instance['album_art' . '_' .  $i] ) ? $instance['album_art' . '_' .  $i] : '';
				$audio_singer    =  isset( $instance['audio_singer' . '_' .  $i] ) ? $instance['audio_singer' . '_' .  $i] : '';
				$audio_link      =  isset( $instance['audio_link' . '_' .  $i] ) ? $instance['audio_link' . '_' .  $i] : '';
				$audio_link_text =  isset( $instance['audio_link_text' . '_' .  $i] ) ? $instance['audio_link_text' . '_' .  $i] : '';
			?>
			<h2> <?php printf( esc_html__( '%1s. Audio Details', 'rock-star-pro' ), $i ); ?> </h2>
			<p>
	        	<label for="<?php echo $this->get_field_id('audio_title' . '_' .  $i ); ?>">
	        		<?php echo esc_html__( 'Title', 'rock-star-pro' ); ?>
	        	</label>

	        	<br />

	        	<input type="text" class="widefat" name="<?php echo $this->get_field_name('audio_title' . '_' .  $i ); ?>" id="<?php echo $this->get_field_id('audio_title' . '_' .  $i ); ?>" value="<?php echo esc_attr( $audio_title ); ?>">
	        </p>

	        <p>
	        	<label for="<?php echo $this->get_field_id('audio_file' . '_' .  $i ); ?>">
	        		<?php echo esc_html__( 'Audio File', 'rock-star-pro' ); ?>
	        	</label>

	        	<br />

	        	<input type="text" class="ct-upload" name="<?php echo $this->get_field_name('audio_file' . '_' .  $i ); ?>" id="<?php echo $this->get_field_id('audio_file' . '_' .  $i ); ?>" value="<?php echo esc_attr( $audio_file ); ?>">
	        	<button class="upload-media-button button button-primary" data-type="audio"><?php esc_html_e( 'Upload', 'rock-star-pro' ); ?></button>
	        </p>

	        <p>
	        	<label for="<?php echo $this->get_field_id('audio_album' . '_' .  $i ); ?>">
	        		<?php echo esc_html__( 'Album', 'rock-star-pro' ); ?>
	        	</label>

	        	<br />

	        	<input type="text" class="widefat" name="<?php echo $this->get_field_name('audio_album' . '_' .  $i ); ?>" id="<?php echo $this->get_field_id('audio_album' . '_' .  $i ); ?>" value="<?php echo esc_attr( $audio_album ); ?>">
	        </p>

	        <p>
	        	<label for="<?php echo $this->get_field_id('album_art' . '_' .  $i ); ?>">
	        		<?php echo esc_html__( 'Album Art', 'rock-star-pro' ); ?>
	        	</label>

	        	<br />

	        	<input type="text" class="ct-upload" name="<?php echo $this->get_field_name('album_art' . '_' .  $i ); ?>" id="<?php echo $this->get_field_id('album_art' . '_' .  $i ); ?>" value="<?php echo esc_attr( $album_art ); ?>">
	        	<button class="upload-media-button button button-primary"><?php esc_html_e( 'Upload', 'rock-star-pro' ); ?></button>
	        	<span class="ct-description small">Please use 180x180 image.</span>
	        </p>

	        <p>
	        	<label for="<?php echo $this->get_field_id('audio_singer' . '_' .  $i ); ?>">
	        		<?php echo esc_html__( 'Singer', 'rock-star-pro' ); ?>
	        	</label>

	        	<br />

	        	<input type="text" class="widefat" name="<?php echo $this->get_field_name('audio_singer' . '_' .  $i ); ?>" id="<?php echo $this->get_field_id('audio_singer' . '_' .  $i ); ?>" value="<?php echo esc_attr( $audio_singer ); ?>">
	        </p>

	        <p>
	        	<label for="<?php echo $this->get_field_id('audio_link' . '_' .  $i ); ?>">
	        		<?php echo esc_html__( 'Buy Link', 'rock-star-pro' ); ?>
	        	</label>

	        	<br />

	        	<input type="text" class="widefat" name="<?php echo $this->get_field_name('audio_link' . '_' .  $i ); ?>" id="<?php echo $this->get_field_id('audio_link' . '_' .  $i ); ?>" value="<?php echo esc_attr( $audio_link ) ; ?>">
	        </p>

	        <p>
	        	<label for="<?php echo $this->get_field_id('audio_link_text' . '_' .  $i ); ?>">
	        		<?php echo esc_html__( 'Buy Link Text', 'rock-star-pro'); ?>
	        	</label>

	        	<br />

	        	<input type="text" class="widefat" name="<?php echo $this->get_field_name('audio_link_text' . '_' .  $i ); ?>" id="<?php echo $this->get_field_id('audio_link_text' . '_' .  $i ); ?>" value="<?php echo esc_attr( $audio_link_text ); ?>">
	        </p>
	    </div><!-- .ct-audio-box -->

	    <?php } //end for
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title']            = sanitize_text_field( $new_instance['title'] );
		$instance['items_number']     = absint( $new_instance['items_number'] );
		$instance['background-image'] = esc_url_raw( $new_instance['background-image'] );

		for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) {
			$instance['audio_title' . '_' .  $i]
				= sanitize_text_field( $new_instance['audio_title' . '_' .  $i] );
			$instance['audio_album' . '_' .  $i]
				= sanitize_text_field( $new_instance['audio_album' . '_' .  $i] );
			$instance['audio_file' . '_' .  $i]
				= wp_kses_stripslashes( $new_instance['audio_file' . '_' .  $i] );
			$instance['album_art' . '_' .  $i]
				= wp_kses_stripslashes( $new_instance['album_art' . '_' .  $i] );
			$instance['audio_singer' . '_' .  $i]
				= sanitize_text_field( $new_instance['audio_singer' . '_' .  $i] );
			$instance['audio_link' . '_' .  $i]
				= esc_url_raw( $new_instance['audio_link' . '_' .  $i] );
			$instance['audio_link_text' . '_' .  $i]
				= sanitize_text_field( $new_instance['audio_link_text' . '_' .  $i] );
		}

		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		echo $args['before_widget'];

		// Set up the author bio
		if ( ! empty( $instance['title'] ) ) {
			echo '
			<header class="entry-header">' . $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'] . '</header><!-- end entry-header -->';
		}

		$audio_list = $audio = array();

		for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) {
			$audio['track']     = $i;
			$audio['name']      = $instance['audio_title' . '_' .  $i];
			$audio['file']      = $instance['audio_file' . '_' .  $i];
			$audio['album']     = $instance['audio_album' . '_' .  $i];
			$audio['album_art'] = isset( $instance['album_art' . '_' .  $i] ) ? $instance['album_art' . '_' .  $i] : '';
			$audio['singer']    = $instance['audio_singer' . '_' .  $i];
			$audio_list[]       = $audio;
		}
		$tracks = $audio_list;

		wp_enqueue_script( 'rock-star-audio-script', get_template_directory_uri().'/js/audio-script.min.js' );
		wp_localize_script( 'rock-star-audio-script', 'track_data', $tracks );
		?>

		<div class="entry-content">
            <div id="mainwrap">
	            <div class="audio-thumbnail">
	                <img id="npAlbumArt" src="<?php echo get_template_directory_uri(); ?>/images/gallery/audio-image-180x180.jpg" alt="audio-thumbnail">
	            </div><!-- .audio-thumbnail -->
                <div id="nowPlay">
                    <span id="npTitle"></span>
                    <span id="npAlbum"></span>
                    <span id="npsinger"></span>
                </div><!-- .nowPlay -->
                <div id="tracks">
                    <a id="btnPrev"><div class="genericon genericon-rewind"></div></a>
                    <a id="btnPlay"><div class="genericon genericon-play"></div></a>
                    <a id="btnNext"><div class="genericon genericon-fastforward"></div></a>
                    <a id="btnRepeat"><div class="genericon genericon-shuffle"></div></a>
                    <a id="btnVolume"><div class="genericon genericon-audio"></div></a>
                </div><!-- #tracks -->
                <div id="audiowrap">
                    <div id="audio0">
                        <audio id="audio1" controls></audio>
                    </div>
                </div><!-- #audiowrap -->
                <div id="plwrap">
                    <ul id="plList">
                   	<?php
                    for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) { ?>
                        <li class="active">
                            <div class="plItem">
                                <div class="plNum"><?php echo $i.'.'; ?></div>

                                <div class="plTitle"><?php echo $instance['audio_title' . '_' .  $i]; ?></div>

                                <div class="buy-now">
                                	<a href="<?php echo esc_url( $instance['audio_link' . '_' .  $i]) ; ?>"><?php echo $instance['audio_link_text' . '_' .  $i]; ?></a>
                                </div>
                            </div>
                        </li>
                    <?php } ?>
                    </ul>
                </div><!-- #plwrap -->
	        </div> <!-- #mainwrap -->
        </div><!-- .entry-content -->
        <?php

		echo $args['after_widget'];

		if ( '' != $instance['background-image'] ) {
			echo '
			<style type="text/css" rel="ct-widget-css '. esc_attr( $args['widget_id'] ) .'">
				#'. esc_attr( $args['widget_id'] ) .' {
					background-image: url('. esc_url( $instance['background-image'] ) .');
					background-position: 50% 50%;
				}
			</style>'
			;
		}
	}
}

//From Codex: https://codex.wordpress.org/Widgets_API
add_action('widgets_init',
	create_function('', 'return register_widget("rock_star_audio_widget");')
);