<?php
/**
 * News Ticker Widget
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Makes a custom Widget for Displaying About
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */
class rock_star_news_ticker_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'news_ticker_option'            => 'homepage',
			'news_ticker_type'              => 'demo-news-ticker',
			'news_ticker_label'             => '',
			'news_ticker_transition_effect' => 'flipVert',
			'post_id'                       => '',
			'category'                      => array(),
			'news_ticker_number'            => 4,
		);

		$widget_ops = array(
			'classname'   => 'ct-news-ticker ctnewticker',
			'description' => esc_html__( 'Use this widget to add News Ticker', 'rock-star-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-news-ticker',
		);

		parent::__construct(
			'ct-news-ticker', // Base ID
			__( 'CT: News Ticker', 'rock-star-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, code, alt
	 * $instance Current settings
	 */
	function form($instance) {
		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		$style = 'style="display: none;"';
		?>
		<p>
            <label for="<?php echo $this->get_field_id( 'news_ticker_option' ); ?>"><?php esc_html_e( 'Enable News Ticker on','rock-star-pro'); ?></label>
        	<select class="widefat" id="<?php echo $this->get_field_id( 'news_ticker_option' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_option' ); ?>">
				<?php
					$new_ticker_enable_options = array(
						'homepage' 		=> esc_html__( 'Homepage / Frontpage', 'rock-star-pro'),
						'entire-site' 	=> esc_html__( 'Entire Site', 'rock-star-pro'),
						'disabled'		=> esc_html__( 'Disabled', 'rock-star-pro' )
					);
					foreach ( $new_ticker_enable_options as $key => $value ) {
						echo '<option value="' . $key . '" '. selected( $key, $instance['news_ticker_option'], false ) .'>' . $value .'</option>';
					}
				?>
			</select>
        </p>

        <p>
			<label for="<?php echo $this->get_field_id( 'news_ticker_type' ); ?>"><?php esc_html_e( 'Select Ticker Type', 'rock-star-pro' ); ?>:</label>
			<select class="ct_feat_post_post_type widefat" id="<?php echo $this->get_field_id( 'news_ticker_type' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_type' ); ?>">
				<?php
					$post_type_choices = array(
						'demo-news-ticker' => esc_html__( 'Demo Content', 'rock-star-pro' ),
						'all-categories'   => esc_html__( 'All Categories', 'rock-star-pro' ),
						'select-category'  => esc_html__( 'Select Category', 'rock-star-pro' ),
						'id'               => esc_html__( 'ID', 'rock-star-pro' ),
						'text-news-ticker' => esc_html__( 'Custom Text News Ticker', 'rock-star-pro' )
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['news_ticker_type'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
			<span class="description"><?php esc_html_e( 'Please save the widget once No. of items is changed to reflect the changes', 'rock-star-pro' ); ?></span>
		</p>

        <p>
            <label for="<?php echo $this->get_field_id( 'news_ticker_transition_effect' ); ?>"><?php esc_html_e( 'Transition Effect','rock-star-pro'); ?></label>
        	<select class="widefat" id="<?php echo $this->get_field_id( 'news_ticker_transition_effect' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_transition_effect' ); ?>">
				<?php
					$news_ticker_transition_effects = array(
						'fade' 		=> esc_html__( 'Fade', 'rock-star-pro' ),
						'fadeout' 	=> esc_html__( 'Fade Out', 'rock-star-pro' ),
						'none' 		=> esc_html__( 'None', 'rock-star-pro' ),
						'scrollHorz'=> esc_html__( 'Scroll Horizontal', 'rock-star-pro' ),
						'scrollVert'=> esc_html__( 'Scroll Vertical', 'rock-star-pro' ),
						'flipHorz'	=> esc_html__( 'Flip Horizontal', 'rock-star-pro' ),
						'flipVert'	=> esc_html__( 'Flip Vertical', 'rock-star-pro' ),
						'tileSlide'	=> esc_html__( 'Tile Slide', 'rock-star-pro' ),
						'tileBlind'	=> esc_html__( 'Tile Blind', 'rock-star-pro' ),
						'shuffle'	=> esc_html__( 'Shuffle', 'rock-star-pro' )
					);
					foreach ( $news_ticker_transition_effects as $key => $value ) {
						echo '<option value="' . $key . '" '. selected( $key, $instance['news_ticker_transition_effect'], false ) .'>' . $value .'</option>';
					}
				?>
			</select>
        </p>

        <p <?php echo ( 'demo-news-ticker' != $instance['news_ticker_type'] )? '' : $style;  ?>>
            <label for="<?php echo $this->get_field_id( 'news_ticker_label' ); ?>"><?php esc_html_e( 'News Ticker Label:','rock-star-pro'); ?></label>
        	<input class="widefat" type="text" name="<?php echo $this->get_field_name( 'news_ticker_label' ); ?>" value="<?php echo esc_attr( $instance['news_ticker_label'] ); ?>" id="<?php echo $this->get_field_id( 'news_ticker_label' ); ?>" />
        </p>

        <p <?php echo ( 'id' == $instance['news_ticker_type'] )? '' : $style;  ?>>
			<label for="<?php echo $this->get_field_id( 'post_id' ); ?>"><?php esc_html_e( 'Post ID', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'post_id' ); ?>" name="<?php echo $this->get_field_name( 'post_id' ); ?>" value="<?php echo sanitize_text_field( $instance['post_id'] ); ?>" class="widefat"/>
			<span class="description"><?php esc_html_e( 'Separate Multiple Post IDs by ,(comma)', 'rock-star-pro' ); ?></span>
		</p>

        <p <?php echo ( 'select-category' == $instance['news_ticker_type'] )? '': $style; ?>>
        	<?php
        		rock_star_dropdown_categories(
        			$this->get_field_name( 'category[]' ),
        			$this->get_field_id( 'category' ),
        			(array) $instance['category']
        		);
        	?>
        </p>

        <p <?php echo ( 'id' == $instance['news_ticker_type'] )? $style : '';  ?>>
			<label for="<?php echo $this->get_field_id( 'news_ticker_number' ); ?>"><?php esc_html_e( 'No. of Posts', 'rock-star-pro' ); ?>:</label>
			<input type="number" id="<?php echo $this->get_field_id( 'news_ticker_number' ); ?>" name="<?php echo $this->get_field_name( 'news_ticker_number' ); ?>" value="<?php echo absint( $instance['news_ticker_number'] ); ?>" class="small-text" min="1" />
			<br>
			<span class="description"><?php esc_html_e( 'Please save the widget once No. of items is changed to reflect the changes', 'rock-star-pro' ); ?></span>
		</p>

        <?php for( $i=1; $i<= absint( $instance['news_ticker_number'] ); $i++ ) {

			$link     =  isset( $instance['custom_news_ticker_link' . '_' .  $i] ) ? $instance['audio_title' . '_' .  $i] : '';
			$target      =  isset( $instance['custom_news_ticker_target' . '_' .  $i] ) ? $instance['audio_file' . '_' .  $i] : '';
			$title     =  isset( $instance['custom_news_ticker_title' . '_' .  $i] ) ? $instance['audio_album' . '_' .  $i] : '';
		?>

        <div class="ct-image-box" <?php echo ( 'text-news-ticker' != $instance['news_ticker_type'] )? $style : '' ;  ?>>

	        <h2> <?php printf( esc_html__( 'Text News Ticker %1s', 'rock-star-pro' ), $i ); ?> </h2>

	        <p>
				<label for="<?php echo $this->get_field_id('custom_news_ticker_title' . '_' .  $i ); ?>"><?php esc_html_e( 'Title', 'rock-star-pro' ); ?>:</label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'custom_news_ticker_title' . '_' .  $i ); ?>" name="<?php echo $this->get_field_name('custom_news_ticker_title' . '_' .  $i ); ?>" value="<?php echo esc_attr( $title ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'custom_news_ticker_link'. '_' .  $i ); ?>"><?php esc_html_e( 'Link', 'rock-star-pro' ); ?>:</label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'custom_news_ticker_link'. '_' .  $i ); ?>" name="<?php echo $this->get_field_name( 'custom_news_ticker_link'. '_' .  $i ); ?>" value="<?php echo esc_attr( $link ); ?>" />
			</p>

			<p>
	            <input class="checkbox" type="checkbox" <?php checked( $target . '_' .  $i, true ) ?> id="<?php echo $this->get_field_id( 'custom_news_ticker_target'. '_' .  $i ); ?>" name="<?php echo $this->get_field_name( 'custom_news_ticker_target'. '_' .  $i ); ?>" />
	        	<label for="<?php echo $this->get_field_id( 'custom_news_ticker_target'. '_' .  $i ); ?>"><?php esc_html_e( 'Check to Open Link in New Window/Tab', 'rock-star-pro' ); ?></label><br />
	        </p>

        </div>

    	<?php } //end for ?>

        <?php
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['news_ticker_option']            = sanitize_key( $new_instance['news_ticker_option'] );
		$instance['news_ticker_type']              = sanitize_key( $new_instance['news_ticker_type'] );
		$instance['news_ticker_label']             = sanitize_text_field( $new_instance['news_ticker_label'] );
		$instance['news_ticker_transition_effect'] = sanitize_text_field( $new_instance['news_ticker_transition_effect'] );
		$instance['news_ticker_number']            = absint( $new_instance['news_ticker_number'] );

		$instance['post_id']        = sanitize_text_field( $new_instance['post_id'] );
		$instance['category']       = ( array ) $new_instance['category'];
		$instance['post_number']    = absint( $new_instance['post_number'] );

		for( $i=1; $i<= absint( $instance['news_ticker_number'] ); $i++ ) {
			$link   =  $instance['custom_news_ticker_link' . '_' .  $i];
			$target =  $instance['custom_news_ticker_target' . '_' .  $i];
			$title  =  $instance['custom_news_ticker_title' . '_' .  $i];
		}



		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$image
			=  isset( $instance['image'] ) ? $instance['image'] : '';

		if ( '' != $image ) {
			echo '
                <section>
	                <div class="widget-wrap">
	                	<header class="entry-header">' . $args['before_title'] . apply_filters( 'widget_title', $instance['headline'], $instance, $this->id_base ) . $args['after_title'] . '<h4 class="sub-title">' . $instance['subheadline'] . '</h4></header><!-- end entry-header -->';

			                $target = '_self';

			                if ( $instance['target'] ) {
			                	$target = '_blank';
			                }

			               	if ( '' != $instance['link_text'] && '' != $instance['link'] ) {
			                	echo '
			                	<div class="view-more aligncenter">
				                    <a href="' . esc_url( $instance['link'] ) . '" title="' . esc_attr( $instance['link_text'] ) . '" target="' . $target . '">' . esc_html( $instance['link_text'] ) . '</a>
				                </div>';
			                }
		                echo '
	                </div><!-- .widget-wrap -->
                </section><!-- .page-section -->
                ';
		}
	}

}

//From Codex: https://codex.wordpress.org/Widgets_API
add_action( 'widgets_init',
	create_function( '', 'return register_widget("rock_star_news_ticker_widget");')
);