<?php
/**
 * Background Image Widget
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Makes a custom Widget for Displaying About
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */
class rock_star_promotion_headline_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'background-image' => '',
			'headline'         => '',
			'subheadline'      => '',
			'link'             => '',
			'link_text'        => esc_html__( 'Buy Now', 'rock-star-pro' ),
			'target'           => 1
		);

		$widget_ops = array(
			'classname'   => 'ct-promotion-headline ctpromotionheadline',
			'description' => esc_html__( 'Use this widget to add Promotion Headline', 'rock-star-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-promotion-headline',
		);

		parent::__construct(
			'ct-promotion-headline', // Base ID
			esc_html__( 'CT: Promotion Headline', 'rock-star-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, code, alt
	 * $instance Current settings
	 */
	function form($instance) {
		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>
		<p>
            <label for="<?php echo $this->get_field_id( 'headline' ); ?>"><?php esc_html_e( 'Headline:','rock-star-pro'); ?></label>
        	<input type="text" name="<?php echo $this->get_field_name( 'headline' ); ?>" value="<?php echo esc_attr( $instance['headline'] ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'headline' ); ?>" />
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'subheadline' ); ?>"><?php esc_html_e( 'Sub Headline:','rock-star-pro'); ?></label>
        	<input type="text" name="<?php echo $this->get_field_name( 'subheadline' ); ?>" value="<?php echo esc_attr( $instance['subheadline'] ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'subheadline' ); ?>" />
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'link' ); ?>"><?php esc_html_e( 'Button Link:','rock-star-pro'); ?></label>
        	<input type="text" name="<?php echo $this->get_field_name( 'link' ); ?>" value="<?php echo $instance['link']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'link' ); ?>" />
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'link_text' ); ?>"><?php esc_html_e( 'Button Text:','rock-star-pro'); ?></label>
        	<input type="text" name="<?php echo $this->get_field_name( 'link_text' ); ?>" value="<?php echo esc_attr( $instance['link_text'] ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'link_text' ); ?>" />
        </p>

        <p>
            <input class="checkbox" type="checkbox" <?php checked($instance['target'], true) ?> id="<?php echo $this->get_field_id( 'target' ); ?>" name="<?php echo $this->get_field_name( 'target' ); ?>" />
        	<label for="<?php echo $this->get_field_id('target'); ?>"><?php esc_html_e( 'Check to open link in new tab/window', 'rock-star-pro' ); ?></label><br />
        </p>

 		<p>
            <label for="<?php echo $this->get_field_id( 'background-image' ); ?>"><?php esc_html_e( 'Background Image Url:','rock-star-pro'); ?></label>
        	<input type="text"  class="ct-upload" name="<?php echo $this->get_field_name( 'background-image' ); ?>" value="<?php echo esc_url( $instance['background-image'] ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'background-image' ); ?>" />
        	<button class="upload-media-button button button-primary"><?php esc_html_e( 'Upload', 'rock-star-pro' ); ?></button>
        </p>
        <?php
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['background-image'] = esc_url_raw( $new_instance['background-image'] );
		$instance['headline']         = sanitize_text_field( $new_instance['headline'] );
		$instance['subheadline']      = sanitize_text_field( $new_instance['subheadline'] );
		$instance['link']             = esc_url_raw( $new_instance['link'] );
		$instance['link_text']        = sanitize_text_field( $new_instance['link_text'] );
		$instance['target']           = rock_star_sanitize_checkbox( $new_instance['target'] );


		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		echo $args['before_widget'];

		if ( '' != $instance['background-image'] ) {
			echo '<div class="background-wrapper">';
		}

		echo '<header class="entry-header">' . $args['before_title'] . apply_filters( 'widget_title', $instance['headline'], $instance, $this->id_base ) . $args['after_title'] . '<h4 class="sub-title">' . $instance['subheadline'] . '</h4></header><!-- end entry-header -->';

            $target = '_self';

            if ( $instance['target'] ) {
            	$target = '_blank';
            }

           	if ( '' != $instance['link_text'] && '' != $instance['link'] ) {
            	echo '
            	<div class="promotion-button">
                    <a class="btn btn-transparent" href="' . esc_url( $instance['link'] ) . '" title="' . esc_attr( $instance['link_text'] ) . '" target="' . $target . '">' . esc_html( $instance['link_text'] ) . '</a>
                </div>';
            }

       	if ( '' != $instance['background-image'] ) {
			echo '</div>';
		}

        echo $args['after_widget'];

        if ( '' != $instance['background-image'] ) {
			echo '
			<style type="text/css" rel="ct-widget-css '. esc_attr( $args['widget_id'] ) .'">
				#'. esc_attr( $args['widget_id'] ) .' {
					background-image: url('. esc_url( $instance['background-image'] ) .');
					background-position: 50% 50%;
				}
			</style>'
			;
		}
	}
}

//From Codex: https://codex.wordpress.org/Widgets_API
add_action( 'widgets_init',
	create_function( '', 'return register_widget("rock_star_promotion_headline_widget");')
);