<?php
/**
 * Recent Posts Widget
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Makes a custom Widget for Displaying About
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */
class rock_star_recet_post_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'title'           => '',
			'number_of_posts' => '3',
			'target'          => 0,
			'more_link'       => '',
			'more_text'       => esc_html__( 'Read More', 'rock-star-pro' ),
		);

		$widget_ops = array(
			'classname'   => 'ct-recent-posts ctrecentposts widget_recent_entries',
			'description' => esc_html__( 'Use this widget to add Recent Posts', 'rock-star-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-recent-posts',
		);

		parent::__construct(
			'ct-recent-posts', // Base ID
			__( 'CT: Recent Posts', 'rock-star-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, code, alt
	 * $instance Current settings
	 */
	function form($instance) {
		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>
        <p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'rock-star-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
		</p>

		<p>
            <label for="<?php echo $this->get_field_id( 'number_of_posts' ); ?>"><?php esc_html_e( 'Number Of posts:','rock-star-pro'); ?></label>
        	<input type="number" name="<?php echo $this->get_field_name( 'number_of_posts' ); ?>" value="<?php echo esc_attr( $instance['number_of_posts'] ); ?>" class="small-text" min="1" id="<?php echo $this->get_field_id( 'number_of_posts' ); ?>" />
        </p>

		<p>
            <label for="<?php echo $this->get_field_id( 'more_link' ); ?>"><?php esc_html_e( 'More Link:','rock-star-pro'); ?></label>
            <br>
        	<input type="text" class="widefat" name="<?php echo $this->get_field_name( 'more_link' ); ?>" value="<?php echo esc_attr( $instance['more_link'] ); ?>" id="<?php echo $this->get_field_id( 'more_link' ); ?>" />
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'more_text' ); ?>"><?php esc_html_e( 'More Text:','rock-star-pro'); ?></label>
            <input type="text" class="widefat" name="<?php echo $this->get_field_name( 'more_text' ); ?>" value="<?php echo esc_attr( $instance['more_text'] ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'more_text' ); ?>" />
        </p>

        <p>
        	<input class="checkbox" type="checkbox" <?php checked( $instance['target'], true ) ?> id="<?php echo $this->get_field_id( 'target' ); ?>" name="<?php echo $this->get_field_name( 'target' ); ?>" />
        	<label for="<?php echo $this->get_field_id( 'target' ); ?>"><?php esc_html_e( 'Check to Open Link in new Tab/Window', 'rock-star-pro' ); ?></label><br />
        </p>

        <?php
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title']           = sanitize_text_field( $new_instance['title'] );
		$instance['number_of_posts'] = absint( $new_instance['number_of_posts'] );
		$instance['target']          = rock_star_sanitize_checkbox( $new_instance['target'] );
		$instance['more_link']       = esc_url_raw( $new_instance['more_link'] );
		$instance['more_text']       = ( $new_instance['more_text'] );

		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$output ='';

		$output .= $args['before_widget'];

		// Set up the author bio
		if ( ! empty( $instance['title'] ) ) {
			$output .= $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'];
		}

		$base = '_self';
		if ( $instance['target'] ) {
			$base = '_blank';
		}

		$query_args = array(
			'post_type'           => 'post',
			'posts_per_page'      => absint( $instance['number_of_posts'] ),
			'ignore_sticky_posts' => '1',
		);

		$loop = new WP_Query( $query_args );

		if ( $loop->have_posts() ) :
			$output .= '<ul>';

				while ( $loop->have_posts() ) : $loop->the_post();

				$title_attribute = the_title_attribute( 'echo=0' );

				$output .= '<li>';

				if ( has_post_thumbnail() ) {
					$output .= '
                        <a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '" alt="'. $title_attribute .'">' .
							get_the_post_thumbnail(
								get_the_ID(),
								'post-thumbnail'
								) .'
						</a>';
				}
				$output .= '
                    <a href="' . esc_url( get_permalink() ) . '">'. $title_attribute .'</a>
                    <time class="entry-date published" datetime="'. get_the_date('c') .'">'. get_the_date('F j, Y').'.</time>
                </li>';

				endwhile;

			$output .= '</ul>';

			if ( '' != $instance['more_link'] && '' != $instance['more_text'] ) {
				$output .= '<div class="view-more aligncenter">
			            <a target="'. $base .'" href="'. esc_url( $instance['more_link'] ) .'">'. esc_html( $instance['more_text']) .'</a>
            		</div>';
			}

			echo $output;

		endif;

		//* Restore original query
		wp_reset_postdata();

		echo $args['after_widget'];
	}

}

//From Codex: https://codex.wordpress.org/Widgets_API
add_action( 'widgets_init',
	create_function( '', 'return register_widget("rock_star_recet_post_widget");')
);